#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__author__ = 'Gunjan Sharma <gunjansharma@google.com>'

import getopt
import getpass
import sys
import gdata.apps.multidomain.client

SCOPE = 'https://apps-apis.google.com/a/feeds/user/'
USER_AGENT = 'MultiDomainQuickStartExample'


class UserData(object):
  """Data corresponding to a single user."""

  def __init__(self):
    self.email = ''
    self.first_name = ''
    self.last_name = ''
    self.password = ''
    self.confirm_password = 'temp'
    self.is_admin = ''
    self.hash_function = ''
    self.suspended = ''
    self.change_password = ''
    self.ip_whitelisted = ''
    self.quota = ''


class MultiDomainQuickStartExample(object):
  """Demonstrates all the functions of multidomain user provisioning."""

  def __init__(self, client_id, client_secret, domain):
    """Constructor for the MultiDomainQuickStartExample object.

    Takes a client_id, client_secret and domain to create an object for
    multidomain user provisioning.

    Args:
      client_id: [string] The clientId of the developer.
      client_secret: [string] The clientSecret of the developer.
      domain: [string] The domain on which the functions are to be performed.
    """
    self.client_id = client_id
    self.client_secret = client_secret
    self.domain = domain
    token = gdata.gauth.OAuth2Token(
        client_id=self.client_id, client_secret=self.client_secret,
        scope=SCOPE, user_agent=USER_AGENT)
    uri = token.generate_authorize_url()
    print 'Please visit this URL to authorize the application:'
    print uri
    # Get the verification code from the standard input.
    code = raw_input('What is the verification code? ').strip()
    token.get_access_token(code)
    self.multidomain_client = (
        gdata.apps.multidomain.client.MultiDomainProvisioningClient(
            domain=self.domain, auth_token=token))

  def _PrintUserDetails(self, entry):
    """Prints all the information for a user entry.

       Args:
         entry: [UserEntry] User entry corresponding to a user
    """

    print 'First Name: %s' % (entry.first_name)
    print 'Last Name: %s' % (entry.last_name)
    print 'Email: %s' % (entry.email)
    print 'Is Admin: %s' % (entry.is_admin)
    print 'Is Suspended: %s' % (entry.suspended)
    print 'Change password at next login: %s' % (
        entry.change_password_at_next_login)
    print '\n'

  def _PrintAliasDetails(self, entry):
    """Prints all the information for a user alias entry.

    Args:
      entry: [AliasEntry] Alias entry correspoding to an alias
    """

    print 'User Email: %s' % (entry.user_email)
    print 'Alias Email: %s' % (entry.alias_email)
    print '\n'

  def _GetChoice(self, for_field):
    """Gets a choice for a field.

    Args:
      for_field: [string] The field for which input is to be taken.

    Return:
      True/False/None: Depending on the choice made by the user.
    """
    choice = int(raw_input(('Enter a choice for %s\n'
                            '1-True 2-False 3-Default/Skip: ') % (for_field)))
    if choice == 1:
      return True
    elif choice == 2:
      return False
    return None

  def _TakeUserData(self, function='create'):
    """Takes input data for _UpdateUser and _CreateUser functions.

    Args:
      function: [string] representing the kind of function (create/update)
          from where this function was called.

    Return:
      user_data: [UserData] All data for a user.
    """
    extra_stmt = ''
    if function == 'update':
      extra_stmt = '. Press enter to not update the field'
    user_data = UserData()
    while not user_data.email:
      user_data.email = raw_input('Enter a valid email address'
                                  '(username@domain.com): ')
    while not user_data.first_name:
      user_data.first_name = raw_input(('Enter first name for the user%s: ')
                                       % (extra_stmt))
      if function == 'update':
        break
    while not user_data.last_name:
      user_data.last_name = raw_input(('Enter last name for the user%s: ')
                                      % (extra_stmt))
      if function == 'update':
        break
    while not user_data.password == user_data.confirm_password:
      user_data.password = ''
      while not user_data.password:
        sys.stdout.write(('Enter password for the user%s: ')
                         % (extra_stmt))
        user_data.password = getpass.getpass()
        if function == 'update' and user_data.password.__len__() == 0:
          break
        if user_data.password.__len__() < 8:
          print 'Password must be at least 8 characters long'
          user_data.password = ''
      if function == 'update' and user_data.password.__len__() == 0:
        break
      sys.stdout.write('Confirm password: ')
      user_data.confirm_password = getpass.getpass()

    user_data.is_admin = self._GetChoice('is_admin')
    user_data.hash_function = raw_input('Enter a hash function or None: ')
    user_data.suspended = self._GetChoice('suspended')
    user_data.change_password = self._GetChoice('change_password')
    user_data.ip_whitelisted = self._GetChoice('ip_whitelisted')
    user_data.quota = raw_input('Enter a quota or None: ')

    if user_data.quota == 'None' or not user_data.quota.isdigit():
      user_data.quota = None
    if user_data.hash_function == 'None':
      user_data.hash_function = None
    return user_data

  def _CreateUser(self):
    """Creates a new user account."""

    user_data = self._TakeUserData()
    self.multidomain_client.CreateUser(
        user_data.email, user_data.first_name, user_data.last_name,
        user_data.password, user_data.is_admin,
        hash_function=user_data.hash_function, suspended=user_data.suspended,
        change_password=user_data.change_password,
        ip_whitelisted=user_data.ip_whitelisted, quota=user_data.quota)

  def _UpdateUser(self):
    """Updates a user."""

    user_data = self._TakeUserData('update')
    user_entry = self.multidomain_client.RetrieveUser(user_data.email)
    if user_data.first_name:
      user_entry.first_name = user_data.first_name
    if user_data.last_name:
      user_entry.last_name = user_data.last_name
    if user_data.password:
      user_entry.password = user_data.password
    if not user_data.hash_function is None:
      user_entry.hash_function = user_data.hash_function
    if not user_data.quota is None:
      user_entry.quota = user_entry.quota
    if not user_data.is_admin is None:
      user_entry.is_admin = (str(user_data.is_admin)).lower()
    if not user_data.suspended is None:
      user_entry.suspended = (str(user_data.suspended)).lower()
    if not user_data.change_password is None:
      user_entry.change_password = (str(user_data.change_password)).lower()
    if not user_data.ip_whitelisted is None:
      user_entry.ip_whitelisted = (str(user_data.ip_whitelisted)).lower()

    self.multidomain_client.UpdateUser(user_data.email, user_entry)

  def _RenameUser(self):
    """Renames username of a user."""

    old_email = ''
    new_email = ''
    while not old_email:
      old_email = raw_input('Enter old email address(username@domain.com): ')
    while not new_email:
      new_email = raw_input('Enter new email address(username@domain.com): ')

    self.multidomain_client.RenameUser(old_email, new_email)

  def _RetrieveSingleUser(self):
    """Retrieves a single user."""

    email = ''
    while not email:
      email = raw_input('Enter a valid email address(username@domain.com): ')

    response = self.multidomain_client.RetrieveUser(email)
    self._PrintUserDetails(response)

  def _RetrieveAllUsers(self):
    """Retrieves all users from all the domains."""

    response = self.multidomain_client.RetrieveAllUsers()
    for entry in response.entry:
      self._PrintUserDetails(entry)

  def _DeleteUser(self):
    """Deletes a user."""

    email = ''
    while not email:
      email = raw_input('Enter a valid email address(username@domain.com): ')

    self.multidomain_client.DeleteUser(email)

  def _CreateUserAlias(self):
    """Creates a user alias."""

    email = ''
    alias = ''
    while not email:
      email = raw_input('Enter a valid email address(username@domain.com): ')
    while not alias:
      alias = raw_input('Enter a valid alias email address'
                        '(username@domain.com): ')
    self.multidomain_client.CreateAlias(email, alias)

  def _RetrieveAlias(self):
    """Retrieves a user corresponding to an alias."""

    alias = ''
    while not alias:
      alias = raw_input('Enter a valid alias email address'
                        '(username@domain.com): ')
    response = self.multidomain_client.RetrieveAlias(alias)
    self._PrintAliasDetails(response)

  def _RetrieveAllAliases(self):
    """Retrieves all user aliases for all users."""

    response = self.multidomain_client.RetrieveAllAliases()
    for entry in response.entry:
      self._PrintAliasDetails(entry)

  def _RetrieveAllUserAliases(self):
    """Retrieves all user aliases of a user."""

    email = ''
    while not email:
      email = raw_input('Enter a valid email address(username@domain.com): ')
    response = self.multidomain_client.RetrieveAllUserAliases(email)
    for entry in response.entry:
      self._PrintAliasDetails(entry)

  def _DeleteAlias(self):
    """Deletes a user alias."""

    alias = ''
    while not alias:
      alias = raw_input('Enter a valid alias email address'
                        '(username@domain.com): ')
    self.multidomain_client.DeleteAlias(alias)

  def Run(self):
    """Runs the sample by getting user input and takin appropriate action."""

    #List of all the function and there description
    functions_list = [
        {'function': self._CreateUser,
         'description': 'Create a user'},
        {'function': self._UpdateUser,
         'description': 'Updating a user'},
        {'function': self._RenameUser,
         'description': 'Renaming a user'},
        {'function': self._RetrieveSingleUser,
         'description': 'Retrieve a single user'},
        {'function': self._RetrieveAllUsers,
         'description': 'Retrieve all users in all domains'},
        {'function': self._DeleteUser,
         'description': 'Deleting a User from a domain'},
        {'function': self._CreateUserAlias,
         'description': 'Create a User Alias in a domain'},
        {'function': self._RetrieveAlias,
         'description': 'Retrieve a User Alias in a domain'},
        {'function': self._RetrieveAllAliases,
         'description': 'Retrieve all User Aliases in a Domain'},
        {'function': self._RetrieveAllUserAliases,
         'description': 'Retrieve all User Aliases for a User'},
        {'function': self._DeleteAlias,
         'description': 'Delete a user alias from a domain'}
    ]

    while True:
      print 'Choose an option:\n0 - to exit'
      for i in range (0, len(functions_list)):
        print '%d - %s' % ((i+1), functions_list[i]['description'])
      choice = int(raw_input())
      if choice == 0:
        break
      if choice < 0 or choice > len(functions_list):
        print 'Not a valid option!'
        continue
      functions_list[choice-1]['function']()


def main():
  """Runs the sample using an instance of MultiDomainQuickStartExample."""

  # Parse command line options
  try:
    opts, args = getopt.getopt(sys.argv[1:], '', ['client_id=',
                                                  'client_secret=',
                                                  'domain='])
  except getopt.error, msg:
    print ('python multidomain_provisioning_quick_start_example.py'
           '--client_id [clientId] --client_secret [clientSecret]'
           '--domain [domain]')
    sys.exit(2)

  client_id = ''
  client_secret = ''
  domain = ''
  # Parse options
  for option, arg in opts:
    if option == '--client_id':
      client_id = arg
    elif option == '--client_secret':
      client_secret = arg
    elif option == '--domain':
      domain = arg

  while not client_id:
    client_id = raw_input('Please enter a clientId: ')
  while not client_secret:
    client_secret = raw_input('Please enter a clientSecret: ')
  while not domain:
    domain = raw_input('Please enter domain name (example.com): ')

  try:
    multidomain_quick_start_example = MultiDomainQuickStartExample(
        client_id, client_secret, domain)
  except gdata.service.BadAuthentication:
    print 'Invalid user credentials given.'
    return

  multidomain_quick_start_example.Run()


if __name__ == '__main__':
  main()



#!/usr/bin/python
#
# Copyright (C) 2008 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


__author__ = 'j.s@google.com (Jeff Scudder)'


import unittest
import atom.token_store
import atom.http_interface
import atom.service
import atom.url

class TokenStoreTest(unittest.TestCase):

  def setUp(self):
    self.token = atom.service.BasicAuthToken('aaa1', scopes=[
        'http://example.com/', 'http://example.org'])
    self.tokens = atom.token_store.TokenStore()
    self.tokens.add_token(self.token)

  def testAddAndFindTokens(self):
    self.assert_(self.tokens.find_token('http://example.com/') == self.token)
    self.assert_(self.tokens.find_token('http://example.org/') == self.token)
    self.assert_(self.tokens.find_token('http://example.org/foo?ok=1') == (
        self.token))
    self.assert_(isinstance(self.tokens.find_token('http://example.net/'),
        atom.http_interface.GenericToken))
    self.assert_(isinstance(self.tokens.find_token('example.com/'), 
        atom.http_interface.GenericToken))

  def testFindTokenUsingMultipleUrls(self):
    self.assert_(self.tokens.find_token(
        'http://example.com/') == self.token)
    self.assert_(self.tokens.find_token(
        'http://example.org/bar') == self.token)
    self.assert_(isinstance(self.tokens.find_token(''), 
        atom.http_interface.GenericToken))
    self.assert_(isinstance(self.tokens.find_token(
            'http://example.net/'), 
        atom.http_interface.GenericToken))

  def testFindTokenWithPartialScopes(self):
    token = atom.service.BasicAuthToken('aaa1', 
        scopes=[atom.url.Url(host='www.example.com', path='/foo'), 
                atom.url.Url(host='www.example.net')])
    token_store = atom.token_store.TokenStore()
    token_store.add_token(token)
    self.assert_(token_store.find_token(
        'http://www.example.com/foobar') == token)
    self.assert_(token_store.find_token(
        'https://www.example.com:443/foobar') == token)
    self.assert_(token_store.find_token(
        'http://www.example.net/xyz') == token)
    self.assert_(token_store.find_token('http://www.example.org/') != token)
    self.assert_(isinstance(token_store.find_token('http://example.org/'), 
        atom.http_interface.GenericToken))


def suite():
  return unittest.TestSuite((unittest.makeSuite(TokenStoreTest,'test'),))


if __name__ == '__main__':
  unittest.main()



"""
Copyright (c) 2008, appengine-utilities project
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
- Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.
- Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.
- Neither the name of the appengine-utilities project nor the names of its
  contributors may be used to endorse or promote products derived from this
  software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
import sys


class Event(object):
    """
    Event is a simple publish/subscribe based event dispatcher. It's a way
    to add, or take advantage of, hooks in your application. If you want to
    tie actions in with lower level classes you're developing within your
    application, you can set events to fire, and then subscribe to them with
    callback methods in other methods in your application.

    It sets itself to the sys.modules['__main__'] function. In order to use it,
    you must import it with your sys.modules['__main__'] method, and make sure
    you import sys.modules['__main__'] and it's accessible for the methods where
    you want to use it.

    For example, from sessions.py

            # if the event class has been loaded, fire off the sessionDeleted
            # event
        if u"AEU_Events" in sys.modules['__main__'].__dict__:
            sys.modules['__main__'].AEU_Events.fire_event(u"sessionDelete")

    You can the subscribe to session delete events, adding a callback

        if u"AEU_Events" in sys.modules['__main__'].__dict__:
            sys.modules['__main__'].AEU_Events.subscribe(u"sessionDelete", \
            clear_user_session)
    """

    def __init__(self):
        self.events = []

    def subscribe(self, event, callback, args = None):
        """
        This method will subscribe a callback function to an event name.

        Args:
            event: The event to subscribe to.
            callback: The callback method to run.
            args: Optional arguments to pass with the callback.

        Returns True
        """
        if not {"event": event, "callback": callback, "args": args, } \
            in self.events:
            self.events.append({"event": event, "callback": callback, \
                "args": args, })
        return True

    def unsubscribe(self, event, callback, args = None):
        """
        This method will unsubscribe a callback from an event.

        Args:
            event: The event to subscribe to.
            callback: The callback method to run.
            args: Optional arguments to pass with the callback.

        Returns True
        """
        if {"event": event, "callback": callback, "args": args, }\
            in self.events:
            self.events.remove({"event": event, "callback": callback,\
                "args": args, })

        return True

    def fire_event(self, event = None):
        """
        This method is what a method uses to fire an event,
        initiating all registered callbacks

        Args:
            event: The name of the event to fire.

        Returns True
        """
        for e in self.events:
            if e["event"] == event:
                if type(e["args"]) == type([]):
                    e["callback"](*e["args"])
                elif type(e["args"]) == type({}):
                    e["callback"](**e["args"])
                elif e["args"] == None:
                    e["callback"]()
                else:
                    e["callback"](e["args"])
        return True
"""
Assign to the event class to sys.modules['__main__']
"""
sys.modules['__main__'].AEU_Events = Event()



#!/usr/bin/python
#
# Copyright 2012 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Sample to list all the members of a group.

The sample demonstrates how to get all members from a group (say Group1)
including members from groups that are members of Group1. It recursively finds
the members of groups that are the member of given group and lists them.
"""

__author__ = 'Shraddha Gupta <shraddhag@google.com>'

from optparse import OptionParser
import gdata.apps.groups.client


SCOPE = 'https://apps-apis.google.com/a/feeds/groups/'
USER_AGENT = 'ListUserMembersFromGroup'


def GetAuthToken(client_id, client_secret):
  """Get an OAuth 2.0 access token using the given client_id and client_secret.

  Client_id and client_secret can be found on the API Access tab on the
  Google APIs Console <http://code.google.com/apis/console>.

  Args:
    client_id: String, client id of the developer.
    client_secret: String, client secret of the developer.

  Returns:
    token: String, authorized OAuth 2.0 token.
  """
  token = gdata.gauth.OAuth2Token(
      client_id=client_id, client_secret=client_secret,
      scope=SCOPE, user_agent=USER_AGENT)
  uri = token.generate_authorize_url()
  print 'Please visit this URL to authorize the application:'
  print uri
  # Get the verification code from the standard input.
  code = raw_input('What is the verification code? ').strip()
  token.get_access_token(code)
  return token


def ListAllMembers(group_client, group_id):
  """Lists all members including members of sub-groups.

  Args:
    group_client: gdata.apps.groups.client.GroupsProvisioningClient instance.
    group_id: String, identifier of the group from which members are listed.

  Returns:
    members_list: List containing the member_id of group members.
  """
  members_list = []
  try:
    group_members = group_client.RetrieveAllMembers(group_id)
    for member in group_members.entry:
      if member.member_type == 'Group':
        temp_list = ListAllMembers(group_client, member.member_id)
        members_list.extend(temp_list)
      else:
        members_list.append(member.member_id)
  except gdata.client.RequestError, e:
    print 'Request error: %s %s %s' % (e.status, e.reason, e.body)
  return members_list


def main():
  """Demonstrates retrieval of members of a group."""
  usage = ('Usage: %prog --DOMAIN <domain> --CLIENT_ID <client_id> '
           '--CLIENT_SECRET <client_secret> --GROUP_ID <group_id> ')
  parser = OptionParser(usage=usage)
  parser.add_option('--DOMAIN',
                    help='Google Apps Domain, e.g. "domain.com".')
  parser.add_option('--CLIENT_ID',
                    help='Registered CLIENT_ID of Domain.')
  parser.add_option('--CLIENT_SECRET',
                    help='Registered CLIENT_SECRET of Domain.')
  parser.add_option('--GROUP_ID',
                    help='Group identifier of the group to list members from.')
  (options, args) = parser.parse_args()

  if not (options.DOMAIN and options.CLIENT_ID and options.CLIENT_SECRET
          and options.GROUP_ID):
    parser.print_help()
    return

  group_client = gdata.apps.groups.client.GroupsProvisioningClient(
      domain=options.DOMAIN)
  token = GetAuthToken(options.CLIENT_ID, options.CLIENT_SECRET)
  token.authorize(group_client)

  members_list = ListAllMembers(group_client, options.GROUP_ID)
  no_duplicate_members_list = list(set(members_list))
  print 'User members of the group %s are: ' % options.GROUP_ID
  print no_duplicate_members_list


if __name__ == '__main__':
  main()



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


__author__ = 'e.bidelman (Eric Bidelman)'

import unittest
import atom
from gdata import test_data
import gdata.acl.data
import gdata.data
import gdata.sites.data
import gdata.test_config as conf


def parse(xml_string, target_class):
  """Convenience wrapper for converting an XML string to an XmlElement."""
  return atom.core.xml_element_from_string(xml_string, target_class)


class CommentEntryTest(unittest.TestCase):

  def setUp(self):
    self.entry = parse(test_data.SITES_COMMENT_ENTRY,
                       gdata.sites.data.ContentEntry)

  def testToAndFromStringCommentEntry(self):
    self.assertEqual(self.entry.Kind(), 'comment')
    self.assert_(isinstance(self.entry.in_reply_to, gdata.sites.data.InReplyTo))
    self.assertEqual(self.entry.in_reply_to.type, 'text/html')
    self.assertEqual(
        self.entry.FindParentLink(),
        'http://sites.google.com/feeds/content/site/gdatatestsite/abc123parent')
    self.assertEqual(
        self.entry.in_reply_to.href,
        'http://sites.google.com/site/gdatatestsite/annoucment/testpost')
    self.assertEqual(
        self.entry.in_reply_to.ref,
        'http://sites.google.com/feeds/content/site/gdatatestsite/abc123')
    self.assertEqual(
        self.entry.in_reply_to.source,
        'http://sites.google.com/feeds/content/site/gdatatestsite')


class ListPageEntryTest(unittest.TestCase):

  def setUp(self):
    self.entry = parse(test_data.SITES_LISTPAGE_ENTRY,
                       gdata.sites.data.ContentEntry)

  def testToAndFromStringWithData(self):
    self.assert_(isinstance(self.entry, gdata.sites.data.ContentEntry))
    self.assertEqual(self.entry.title.text, 'ListPagesTitle')
    self.assertEqual(len(self.entry.author), 1)
    self.assertEqual(self.entry.author[0].name.text, 'Test User')
    self.assertEqual(self.entry.author[0].email.text, 'test@gmail.com')
    self.assertEqual(self.entry.worksheet.name, 'listpage')
    self.assertEqual(self.entry.header.row, '1')
    self.assertEqual(self.entry.data.startRow, '2')
    self.assertEqual(len(self.entry.data.column), 5)
    self.assert_(isinstance(self.entry.data.column[0], gdata.sites.data.Column))
    self.assertEqual(self.entry.data.column[0].index, 'A')
    self.assertEqual(self.entry.data.column[0].name, 'Owner')
    self.assert_(isinstance(self.entry.feed_link, gdata.data.FeedLink))
    self.assertEqual(
        self.entry.feed_link.href,
        'http:///sites.google.com/feeds/content/site/gdatatestsite?parent=abc')
    self.assert_(isinstance(self.entry.content, gdata.sites.data.Content))
    self.assert_(isinstance(self.entry.content.html, atom.core.XmlElement))
    self.assertEqual(self.entry.content.type, 'xhtml')


class ListItemEntryTest(unittest.TestCase):

  def setUp(self):
    self.entry = parse(test_data.SITES_LISTITEM_ENTRY,
                       gdata.sites.data.ContentEntry)

  def testToAndFromStringWithData(self):
    self.assert_(isinstance(self.entry, gdata.sites.data.ContentEntry))
    self.assertEqual(len(self.entry.field), 5)
    self.assert_(isinstance(self.entry.field[0], gdata.sites.data.Field))
    self.assertEqual(self.entry.field[0].index, 'A')
    self.assertEqual(self.entry.field[0].name, 'Owner')
    self.assertEqual(self.entry.field[0].text, 'test value')
    self.assertEqual(
        self.entry.FindParentLink(),
        'http://sites.google.com/feeds/content/site/gdatatestsite/abc123def')


class BaseSiteEntryTest(unittest.TestCase):

  def testCreateBaseSiteEntry(self):
    entry = gdata.sites.data.BaseSiteEntry()
    parent_link = atom.data.Link(
        rel=gdata.sites.data.SITES_PARENT_LINK_REL, href='abc')
    entry.link.append(parent_link)
    entry.category.append(
        atom.data.Category(
            scheme=gdata.sites.data.SITES_KIND_SCHEME,
            term='%s#%s' % (gdata.sites.data.SITES_NAMESPACE, 'webpage'),
            label='webpage'))
    self.assertEqual(entry.Kind(), 'webpage')
    self.assertEqual(entry.category[0].label, 'webpage')
    self.assertEqual(
        entry.category[0].term,
        '%s#%s' % ('http://schemas.google.com/sites/2008', 'webpage'))
    self.assertEqual(entry.link[0].href, 'abc')
    self.assertEqual(entry.link[0].rel,
                     'http://schemas.google.com/sites/2008#parent')

    entry2 = gdata.sites.data.BaseSiteEntry(kind='webpage')
    self.assertEqual(
        entry2.category[0].term,
        '%s#%s' % ('http://schemas.google.com/sites/2008', 'webpage'))


class ContentFeedTest(unittest.TestCase):

  def setUp(self):
    self.feed = parse(test_data.SITES_CONTENT_FEED,
                      gdata.sites.data.ContentFeed)

  def testToAndFromStringContentFeed(self):
    self.assert_(isinstance(self.feed, gdata.sites.data.ContentFeed))
    self.assertEqual(len(self.feed.entry), 8)
    self.assert_(isinstance(self.feed.entry[0].revision,
                            gdata.sites.data.Revision))
    self.assertEqual(int(self.feed.entry[0].revision.text), 2)
    self.assertEqual(self.feed.entry[0].GetNodeId(), '1712987567114738703')
    self.assert_(isinstance(self.feed.entry[0].page_name,
                            gdata.sites.data.PageName))
    self.assertEqual(self.feed.entry[0].page_name.text, 'home')
    self.assertEqual(self.feed.entry[0].FindRevisionLink(),
        'http:///sites.google.com/feeds/content/site/gdatatestsite/12345')
    for entry in self.feed.entry:
      self.assert_(isinstance(entry, gdata.sites.data.ContentEntry))
      if entry.deleted is not None:
        self.assert_(isinstance(entry.deleted, gdata.sites.data.Deleted))
        self.assertEqual(entry.IsDeleted(), True)
      else:
        self.assertEqual(entry.IsDeleted(), False)

  def testCreateContentEntry(self):
    new_entry = gdata.sites.data.ContentEntry()
    new_entry.content = gdata.sites.data.Content()
    new_entry.content.html = '<div><p>here is html</p></div>'
    self.assert_(isinstance(new_entry, gdata.sites.data.ContentEntry))
    self.assert_(isinstance(new_entry.content, gdata.sites.data.Content))
    self.assert_(isinstance(new_entry.content.html, atom.core.XmlElement))

    new_entry2 = gdata.sites.data.ContentEntry()
    new_entry2.content = gdata.sites.data.Content(
        html='<div><p>here is html</p></div>')
    self.assert_(isinstance(new_entry2, gdata.sites.data.ContentEntry))
    self.assert_(isinstance(new_entry2.content, gdata.sites.data.Content))
    self.assert_(isinstance(new_entry2.content.html, atom.core.XmlElement))

  def testGetHelpers(self):
    kinds = {'announcement': self.feed.GetAnnouncements,
             'announcementspage': self.feed.GetAnnouncementPages,
             'attachment': self.feed.GetAttachments,
             'comment': self.feed.GetComments,
             'filecabinet': self.feed.GetFileCabinets,
             'listitem': self.feed.GetListItems,
             'listpage': self.feed.GetListPages,
             'webpage': self.feed.GetWebpages}

    for k, v in kinds.iteritems():
      entries = v()
      self.assertEqual(len(entries), 1)
      for entry in entries:
        self.assertEqual(entry.Kind(), k)
        if k == 'attachment':
          self.assertEqual(entry.GetAlternateLink().href,
                           'http://sites.google.com/feeds/SOMELONGURL')


class ActivityFeedTest(unittest.TestCase):

  def setUp(self):
    self.feed = parse(test_data.SITES_ACTIVITY_FEED,
                      gdata.sites.data.ActivityFeed)

  def testToAndFromStringActivityFeed(self):
    self.assert_(isinstance(self.feed, gdata.sites.data.ActivityFeed))
    self.assertEqual(len(self.feed.entry), 2)
    for entry in self.feed.entry:
      self.assert_(isinstance(entry.summary, gdata.sites.data.Summary))
      self.assertEqual(entry.summary.type, 'xhtml')
      self.assert_(isinstance(entry.summary.html, atom.core.XmlElement))


class RevisionFeedTest(unittest.TestCase):

  def setUp(self):
    self.feed = parse(test_data.SITES_REVISION_FEED,
                      gdata.sites.data.RevisionFeed)

  def testToAndFromStringRevisionFeed(self):
    self.assert_(isinstance(self.feed, gdata.sites.data.RevisionFeed))
    self.assertEqual(len(self.feed.entry), 1)
    entry = self.feed.entry[0]
    self.assert_(isinstance(entry.content, gdata.sites.data.Content))
    self.assert_(isinstance(entry.content.html, atom.core.XmlElement))
    self.assertEqual(entry.content.type, 'xhtml')
    self.assertEqual(
        entry.FindParentLink(),
        'http://sites.google.com/feeds/content/site/siteName/54395424125706119')


class SiteFeedTest(unittest.TestCase):

  def setUp(self):
    self.feed = parse(test_data.SITES_SITE_FEED,
                      gdata.sites.data.SiteFeed)

  def testToAndFromStringSiteFeed(self):
    self.assert_(isinstance(self.feed, gdata.sites.data.SiteFeed))
    self.assertEqual(len(self.feed.entry), 2)
    entry = self.feed.entry[0]
    self.assert_(isinstance(entry.site_name, gdata.sites.data.SiteName))
    self.assertEqual(entry.title.text, 'New Test Site')
    self.assertEqual(entry.site_name.text, 'new-test-site')
    self.assertEqual(
        entry.FindAclLink(),
        'http://sites.google.com/feeds/acl/site/example.com/new-test-site')
    self.assertEqual(
        entry.FindSourceLink(),
        'http://sites.google.com/feeds/site/example.com/source-site')
    self.assertEqual(entry.theme.text, 'iceberg')


class AclFeedTest(unittest.TestCase):

  def setUp(self):
    self.feed = parse(test_data.SITES_ACL_FEED,
                      gdata.sites.data.AclFeed)

  def testToAndFromStringAclFeed(self):
    self.assert_(isinstance(self.feed, gdata.sites.data.AclFeed))
    self.assertEqual(len(self.feed.entry), 1)
    entry = self.feed.entry[0]
    self.assert_(isinstance(entry, gdata.sites.data.AclEntry))
    self.assert_(isinstance(entry.scope, gdata.acl.data.AclScope))
    self.assertEqual(entry.scope.type, 'user')
    self.assertEqual(entry.scope.value, 'user@example.com')
    self.assert_(isinstance(entry.role, gdata.acl.data.AclRole))
    self.assertEqual(entry.role.value, 'owner')
    self.assertEqual(
        entry.GetSelfLink().href,
        ('https://sites.google.com/feeds/acl/site/example.com/'
         'new-test-site/user%3Auser%40example.com'))


class DataClassSanityTest(unittest.TestCase):

  def test_basic_element_structure(self):
    conf.check_data_classes(self, [
        gdata.sites.data.Revision, gdata.sites.data.PageName,
        gdata.sites.data.Deleted, gdata.sites.data.Publisher,
        gdata.sites.data.Worksheet, gdata.sites.data.Header,
        gdata.sites.data.Column, gdata.sites.data.Data,
        gdata.sites.data.Field, gdata.sites.data.InReplyTo,
        gdata.sites.data.BaseSiteEntry, gdata.sites.data.ContentEntry,
        gdata.sites.data.ContentFeed, gdata.sites.data.ActivityEntry,
        gdata.sites.data.ActivityFeed, gdata.sites.data.RevisionEntry,
        gdata.sites.data.RevisionFeed, gdata.sites.data.Content,
        gdata.sites.data.Summary, gdata.sites.data.SiteName,
        gdata.sites.data.SiteEntry, gdata.sites.data.SiteFeed,
        gdata.sites.data.AclEntry, gdata.sites.data.AclFeed,
        gdata.sites.data.Theme])


def suite():
  return conf.build_suite([
      CommentEntryTest, ListPageEntryTest, ListItemEntryTest, BaseSiteEntryTest,
      ContentFeedTest, ActivityFeedTest, RevisionFeedTest, SiteFeedTest,
      AclFeedTest, DataClassSanityTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__author__ = 'Gunjan Sharma <gunjansharma@google.com>'

import getopt
import sys
import gdata.apps.groups.client
import gdata.apps.groups.data

SCOPE = 'https://apps-apis.google.com/a/feeds/groups/'
USER_AGENT = 'GroupsQuickStartExample'


class GroupsQuickStartExample(object):
  """Demonstrates all the functions of Groups provisioning."""

  def __init__(self, client_id, client_secret, domain):
    """Constructor for the GroupsQuickStartExample object.

    Takes a client_id, client_secret and domain needed to create an object for
    groups provisioning.

    Args:
      client_id: [string] The clientId of the developer.
      client_secret: [string] The clientSecret of the developer.
      domain: [string] The domain on which the functions are to be performed.
    """
    self.client_id = client_id
    self.client_secret = client_secret
    self.domain = domain

  def CreateGroupsClient(self):
    """Creates a groups provisioning client using OAuth2.0 flow."""
    token = gdata.gauth.OAuth2Token(
        client_id=self.client_id, client_secret=self.client_secret,
        scope=SCOPE, user_agent=USER_AGENT)
    uri = token.generate_authorize_url()
    print 'Please visit this URL to authorize the application:'
    print uri
    # Get the verification code from the standard input.
    code = raw_input('What is the verification code? ').strip()
    token.get_access_token(code)
    self.groups_client = gdata.apps.groups.client.GroupsProvisioningClient(
        domain=self.domain, auth_token=token)

  def _GetValidGroupId(self):
    """Takes a valid group email address as input.

    Return:
      group_id: [string] a valid group email address
    """
    group_id = ''
    while not group_id:
      group_id = raw_input('Enter a valid group email address'
                           '(group@domain.com): ')
    return group_id

  def _GetValidMemberId(self):
    """Takes a valid member email address as input.

    Return:
      member_id: [string] a valid member email address
    """
    member_id = ''
    while not member_id:
      member_id = raw_input('Enter a valid member email address'
                            '(username@domain.com): ')
    return member_id

  def _PrintGroupDetails(self, group_entry):
    """Print all the details of a group.

    Args:
      group_entry: [GroupEntry] contains all the data about the group.
    """
    print 'Group ID: ' + group_entry.group_id
    print 'Group Name: ' + group_entry.group_name
    print 'Description: ' + group_entry.description
    print 'Email Permissions: ' + group_entry.email_permission
    print ''

  def _PrintMemberDetails(self, member_entry):
    """Print all the details of a group member.

    Args:
      member_entry: [GroupMemberEntry] contains all the data about the group member.
    """
    print 'Member ID: ' + member_entry.member_id
    print 'Member Type: ' + member_entry.member_type
    print 'Is Direct Member: ' + member_entry.direct_member
    print ''

  def _TakeGroupData(self, function='create'):
    """Takes input data for _UpdateGroup and _CreateGroup functions.

    Args:
      function: [string] representing the kind of function (create/update)
          from where this function was called.

    Return:
      group_data: [gdata.apps.groups.data.GroupEntry] All data for a group.
    """
    email_permission_options = ['Owner', 'Member', 'Domain', 'Anyone']
    extra_stmt = ''
    if function == 'update':
      extra_stmt = '. Press enter to not update the field'
    group_data = gdata.apps.groups.data.GroupEntry()
    group_data.group_id = self._GetValidGroupId()
    while not group_data.group_name:
      group_data.group_name = raw_input('Enter name for the group%s: '
                                        % extra_stmt)
      if function == 'update':
        break
    group_data.description = raw_input('Enter description for the group%s: '
                                       % extra_stmt)

    print ('Choose an option for email permission%s:'
           % extra_stmt)
    i = 1
    for option in email_permission_options:
      print '%d - %s' % (i, option)
      i += 1
    choice = (raw_input())
    if not choice:
      choice = -1
    choice = int(choice)
    if choice > 0 and choice <= len(email_permission_options):
      group_data.email_permission = email_permission_options[choice-1]

    return group_data

  def _CreateGroup(self):
    """Creates a new group."""
    group_data = self._TakeGroupData()
    self.groups_client.CreateGroup(group_data.group_id,
                                   group_data.group_name,
                                   group_data.description,
                                   group_data.email_permission)

  def _UpdateGroup(self):
    """Updates an existing group."""
    group_data = self._TakeGroupData(function='update')
    group_entry = self.groups_client.RetrieveGroup(group_data.group_id)
    if group_data.group_name:
      group_entry.group_name = group_data.group_name
    if group_data.description:
      group_entry.description = group_data.description
    if group_data.email_permission:
      group_entry.email_permission = group_data.email_permission

    self.groups_client.UpdateGroup(group_data.GetGroupId(), group_entry)

  def _RetrieveSingleGroup(self):
    """Retrieves a single group."""
    group_id = self._GetValidGroupId()
    group_entry = self.groups_client.RetrieveGroup(group_id)
    self._PrintGroupDetails(group_entry)

  def _RetrieveAllGroupsForMember(self):
    """Retrieves all the groups the user is a member of."""
    member_id = self._GetValidMemberId()
    direct_only = raw_input('Write true/false for direct_only: ')
    if direct_only == 'true':
      direct_only = True
    else:
      direct_only = False
    groups_feed = self.groups_client.RetrieveGroups(member_id, direct_only)
    for entry in groups_feed.entry:
      self._PrintGroupDetails(entry)

  def _RetrieveAllGroups(self):
    """Retrieves all the groups in a domain."""
    groups_feed = self.groups_client.RetrieveAllGroups()
    for entry in groups_feed.entry:
      self._PrintGroupDetails(entry)

  def _DeleteGroup(self):
    """Delete a group."""
    group_id = self._GetValidGroupId()
    self.groups_client.DeleteGroup(group_id)

  def _AddMemberToGroup(self):
    """Add a member to a particular group."""
    group_id = self._GetValidGroupId()
    member_id = self._GetValidMemberId()
    self.groups_client.AddMemberToGroup(group_id, member_id)

  def _RetrieveSingleMember(self):
    """Retrieve a single member from a group."""
    group_id = self._GetValidGroupId()
    member_id = self._GetValidMemberId()
    member_entry = self.groups_client.RetrieveGroupMember(group_id, member_id)
    self._PrintMemberDetails(member_entry)

  def _RetrieveAllMembersOfGroup(self):
    """Retrieve all the members of a group."""
    group_id = self._GetValidGroupId()
    members_feed = self.groups_client.RetrieveAllMembers(group_id)
    for entry in members_feed.entry:
      self._PrintMemberDetails(entry)

  def _RemoveMemberFromGroup(self):
    """Remove a member from a group."""
    group_id = self._GetValidGroupId()
    member_id = self._GetValidMemberId()
    self.groups_client.RemoveMemberFromGroup(group_id, member_id)

  def Run(self):
    """Runs the sample by getting user input and takin appropriate action."""
    #List of all the function and there description
    functions_list = [
        {'function': self._CreateGroup,
         'description': 'Create a Group'},
        {'function': self._UpdateGroup,
         'description': 'Updating a Group'},
        {'function': self._RetrieveSingleGroup,
         'description': 'Retrieve a single Group'},
        {'function': self._RetrieveAllGroupsForMember,
         'description': 'Retrieve all Groups for a member'},
        {'function': self._RetrieveAllGroups,
         'description': 'Retrieve all Groups in a domain'},
        {'function': self._DeleteGroup,
         'description': 'Deleting a Group from a domain'},
        {'function': self._AddMemberToGroup,
         'description': 'Add a member to a Group'},
        {'function': self._RetrieveSingleMember,
         'description': 'Retrieve a member of a group'},
        {'function': self._RetrieveAllMembersOfGroup,
         'description': 'Retrieve all members of a group'},
        {'function': self._RemoveMemberFromGroup,
         'description': 'Delete a member from a Group'}
    ]

    while True:
      print 'Choose an option:\n0 - to exit'
      for i in range (0, len(functions_list)):
        print '%d - %s' % ((i+1), functions_list[i]['description'])
      choice = int(raw_input())
      if choice == 0:
        break
      if choice < 0 or choice > len(functions_list):
        print 'Not a valid option!'
        continue
      functions_list[choice-1]['function']()


def main():
  """Runs the sample using an instance of GroupsQuickStartExample."""
  # Parse command line options
  try:
    opts, args = getopt.getopt(sys.argv[1:], '', ['client_id=',
                                                  'client_secret=',
                                                  'domain='])
  except getopt.error, msg:
    print ('python groups_provisioning_quick_start_example.py'
           ' --client_id [clientId] --client_secret [clientSecret]'
           ' --domain [domain]')
    sys.exit(2)

  client_id = ''
  client_secret = ''
  domain = ''
  # Parse options
  for option, arg in opts:
    if option == '--client_id':
      client_id = arg
    elif option == '--client_secret':
      client_secret = arg
    elif option == '--domain':
      domain = arg

  while not client_id:
    client_id = raw_input('Please enter a clientId: ')
  while not client_secret:
    client_secret = raw_input('Please enter a clientSecret: ')
  while not domain:
    domain = raw_input('Please enter domain name (example.com): ')

  try:
    groups_quick_start_example = GroupsQuickStartExample(
        client_id, client_secret, domain)
  except gdata.service.BadAuthentication:
    print 'Invalid user credentials given.'
    return

  groups_quick_start_example.CreateGroupsClient()
  groups_quick_start_example.Run()


if __name__ == '__main__':
  main()



#!/usr/bin/env python
#
# Copyright (C) 2009 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This module is used for version 2 of the Google Data APIs.

__author__ = 'jlapenna@google.com (Joe LaPenna)'


import unittest

from gdata import test_data

import gdata.projecthosting.data
import atom.core
import gdata.test_config as conf


ISSUE_ENTRY = """\
<entry xmlns='http://www.w3.org/2005/Atom'
        xmlns:issues='http://schemas.google.com/projecthosting/issues/2009'>
  <id>http://code.google.com/feeds/issues/p/PROJECT_NAME/issues/full/1</id>
  <updated>2009-09-09T20:34:35.365Z</updated>
  <title>This is updated issue summary</title>
  <content type='html'>This is issue description</content>
  <link rel='self' type='application/atom+xml'
      href='http://code.google.com/feeds/issues/p/PROJECT_NAME/issues/full/3'/>
  <link rel='edit' type='application/atom+xml'
      href='http://code.google.com/feeds/issues/p/PROJECT_NAME/issues/full/3'/>
  <author>
    <name>elizabeth.bennet</name>
    <uri>/u/elizabeth.bennet/</uri>
  </author>
  <issues:cc>
    <issues:uri>/u/@UBhTQl1UARRAVga7/</issues:uri>
    <issues:username>mar...@domain.com</issues:username>
  </issues:cc>
  <issues:cc>
    <issues:uri>/u/fitzwilliam.darcy/</issues:uri>
    <issues:username>fitzwilliam.darcy</issues:username>
  </issues:cc>
  <issues:label>Type-Enhancement</issues:label>
  <issues:label>Priority-Low</issues:label>
  <issues:owner>
    <issues:uri>/u/charlotte.lucas/</issues:uri>
    <issues:username>charlotte.lucas</issues:username>
  </issues:owner>
  <issues:stars>0</issues:stars>
  <issues:state>open</issues:state>
  <issues:status>Started</issues:status>
</entry>
"""

ISSUES_FEED = """\
<?xml version='1.0' encoding='UTF-8'?>
<feed xmlns='http://www.w3.org/2005/Atom'>
  <id>http://code.google.com/feeds/issues/p/android-test2/issues/full</id>
  <link href="http://code.google.com/feeds/issues/p/android-test2/issues/full"
      rel="http://schemas.google.com/g/2005#feed" type="application/atom+xml" />
  <link href="http://code.google.com/feeds/issues/p/android-test2/issues/full"
      rel="http://schemas.google.com/g/2005#post" type="application/atom+xml" />
  <link href="http://code.google.com/feeds/issues/p/android-test2/issues/full"
      rel="self" type="application/atom+xml" />
  <updated>2009-09-22T04:06:32.794Z</updated>
  %s
</feed>
""" % ISSUE_ENTRY


COMMENT_ENTRY = """\
<?xml version='1.0' encoding='UTF-8'?>
<entry xmlns='http://www.w3.org/2005/Atom'
    xmlns:issues='http://schemas.google.com/projecthosting/issues/2009'>
  <content type='html'>This is comment - update issue</content>
  <author>
    <name>elizabeth.bennet</name>
  </author>
  <issues:updates>
    <issues:summary>This is updated issue summary</issues:summary>
    <issues:status>Started</issues:status>
    <issues:ownerUpdate>charlotte.lucas</issues:ownerUpdate>
    <issues:label>-Type-Defect</issues:label>
    <issues:label>Type-Enhancement</issues:label>
    <issues:label>-Milestone-2009</issues:label>
    <issues:label>-Priority-Medium</issues:label>
    <issues:label>Priority-Low</issues:label>
    <issues:ccUpdate>-fitzwilliam.darcy</issues:ccUpdate>
    <issues:ccUpdate>marialucas@domain.com</issues:ccUpdate>
  </issues:updates>
</entry>
"""


class CommentEntryTest(unittest.TestCase):

  def testParsing(self):
    entry = atom.core.parse(COMMENT_ENTRY,
                            gdata.projecthosting.data.CommentEntry)

    updates = entry.updates

    self.assertEquals(updates.summary.text, 'This is updated issue summary')
    self.assertEquals(updates.status.text, 'Started')
    self.assertEquals(updates.ownerUpdate.text, 'charlotte.lucas')

    self.assertEquals(len(updates.label), 5)
    self.assertEquals(updates.label[0].text, '-Type-Defect')
    self.assertEquals(updates.label[1].text, 'Type-Enhancement')
    self.assertEquals(updates.label[2].text, '-Milestone-2009')
    self.assertEquals(updates.label[3].text, '-Priority-Medium')
    self.assertEquals(updates.label[4].text, 'Priority-Low')

    self.assertEquals(len(updates.ccUpdate), 2)
    self.assertEquals(updates.ccUpdate[0].text, '-fitzwilliam.darcy')
    self.assertEquals(updates.ccUpdate[1].text, 'marialucas@domain.com')


class IssueEntryTest(unittest.TestCase):

  def testParsing(self):
    entry = atom.core.parse(ISSUE_ENTRY, gdata.projecthosting.data.IssueEntry)

    self.assertEquals(entry.owner.uri.text, '/u/charlotte.lucas/')
    self.assertEqual(entry.owner.username.text, 'charlotte.lucas')

    self.assertEquals(len(entry.cc), 2)
    cc_0 = entry.cc[0]
    self.assertEquals(cc_0.uri.text, '/u/@UBhTQl1UARRAVga7/')
    self.assertEquals(cc_0.username.text, 'mar...@domain.com')
    cc_1 = entry.cc[1]
    self.assertEquals(cc_1.uri.text, '/u/fitzwilliam.darcy/')
    self.assertEquals(cc_1.username.text, 'fitzwilliam.darcy')

    self.assertEquals(len(entry.label), 2)
    self.assertEquals(entry.label[0].text, 'Type-Enhancement')
    self.assertEquals(entry.label[1].text, 'Priority-Low')

    self.assertEquals(entry.stars.text, '0')
    self.assertEquals(entry.state.text, 'open')
    self.assertEquals(entry.status.text, 'Started')


class DataClassSanityTest(unittest.TestCase):

  def test_basic_element_structure(self):
    conf.check_data_classes(self, [
        gdata.projecthosting.data.Uri,
        gdata.projecthosting.data.Username,
        gdata.projecthosting.data.Cc,
        gdata.projecthosting.data.Label,
        gdata.projecthosting.data.Owner,
        gdata.projecthosting.data.Stars,
        gdata.projecthosting.data.State,
        gdata.projecthosting.data.Status,
        gdata.projecthosting.data.Summary,
        gdata.projecthosting.data.Updates,
        gdata.projecthosting.data.IssueEntry,
        gdata.projecthosting.data.IssuesFeed,
        gdata.projecthosting.data.CommentEntry,
        gdata.projecthosting.data.CommentsFeed])


def suite():
  return conf.build_suite([IssueEntryTest, DataClassSanityTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/env python
#
# Copyright (C) 2010 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# This module is used for version 2 of the Google Data APIs.


__author__ = 'j.s@google.com (Jeff Scudder)'


import unittest
import gdata.core
import gdata.test_config as conf 



PLAYLIST_EXAMPLE = (
    '{"apiVersion": "2.0","data": {"totalResults": 347,"startIndex": 1,"it'
    'emsPerPage": 2,"items": [{"id": "4DAEFAF23BB3CDD0","created": "2008-1'
    '2-09T20:23:06.000Z","updated": "2010-01-04T02:56:19.000Z","author": "'
    'GoogleDevelopers","title": "Google Web Toolkit Developers","descripti'
    'on": "Developers talk about using Google Web Toolkit ...","tags": ["g'
    'oogle","web","toolkit","developers","gwt"],"size": 12},{"id": "586D32'
    '2B5E2764CF","created": "2007-11-13T19:41:21.000Z","updated": "2010-01'
    '-04T17:41:16.000Z","author": "GoogleDevelopers","title": "Android","d'
    'escription": "Demos and tutorials about the new Android platform.","t'
    'ags": ["android","google","developers","mobile"],"size": 32}]}}')


VIDEO_EXAMPLE = (
    '{"apiVersion": "2.0","data": {"updated": "2010-01-07T19:58:42.949Z","'
    'totalItems": 800,"startIndex": 1,"itemsPerPage": 1, "items": [{"id": '
    '"hYB0mn5zh2c","uploaded": "2007-06-05T22:07:03.000Z","updated": "2010'
    '-01-07T13:26:50.000Z","uploader": "GoogleDeveloperDay","category": "N'
    'ews","title": "Google Developers Day US - Maps API Introduction","des'
    'cription": "Google Maps API Introduction ...","tags": ["GDD07","GDD07'
    'US","Maps"],"thumbnail": {"default": "http://i.ytimg.com/vi/hYB0mn5zh'
    '2c/default.jpg","hqDefault": "http://i.ytimg.com/vi/hYB0mn5zh2c/hqdef'
    'ault.jpg"},"player": {"default": "http://www.youtube.com/watch?v'
    '\u003dhYB0mn5zh2c"},"content": {"1": "rtsp://v5.cache3.c.youtube.com/'
    'CiILENy.../0/0/0/video.3gp","5": "http://www.youtube.com/v/hYB0mn5zh2'
    'c?f...","6": "rtsp://v1.cache1.c.youtube.com/CiILENy.../0/0/0/video.3'
    'gp"},"duration": 2840,"rating": 4.63,"ratingCount": 68,"viewCount": 2'
    '20101,"favoriteCount": 201,"commentCount": 22}]}}')


class JsoncConversionTest(unittest.TestCase):
  
  # See http://code.google.com/apis/youtube/2.0/developers_guide_jsonc.html 
  def test_from_and_to_old_json(self):
    json = ('{"media$group":{"media$credit":[{"$t":"GoogleDevelopers", '
            '"role":"uploader", "scheme":"urn:youtube"}]}}')
    jsonc_obj = gdata.core.parse_json(json)
    self.assert_(isinstance(jsonc_obj, gdata.core.Jsonc))
    raw = gdata.core._convert_to_object(jsonc_obj)
    self.assertEqual(raw['media$group']['media$credit'][0]['$t'],
                     'GoogleDevelopers')

  def test_to_and_from_jsonc(self):
    x = {'a': 1}
    jsonc_obj = gdata.core._convert_to_jsonc(x)
    self.assertEqual(jsonc_obj.a, 1)
    # Convert the json_obj back to a dict and compare.
    self.assertEqual(x, gdata.core._convert_to_object(jsonc_obj))

  def test_from_and_to_new_json(self):
    x = gdata.core.parse_json(PLAYLIST_EXAMPLE)
    self.assertEqual(x._dict['apiVersion'], '2.0')
    self.assertEqual(x._dict['data']._dict['items'][0]._dict['id'],
                     '4DAEFAF23BB3CDD0')
    self.assertEqual(x._dict['data']._dict['items'][1]._dict['id'],
                     '586D322B5E2764CF')
    x = gdata.core.parse_json(VIDEO_EXAMPLE)
    self.assertEqual(x._dict['apiVersion'], '2.0')
    self.assertEqual(x.data._dict['totalItems'], 800)
    self.assertEqual(x.data.items[0]._dict['viewCount'], 220101)

  def test_pretty_print(self):
    x = gdata.core.Jsonc(x=1, y=2, z=3)
    pretty = gdata.core.prettify_jsonc(x)
    self.assert_(isinstance(pretty, (str, unicode)))
    
    pretty = gdata.core.prettify_jsonc(x, 4)
    self.assert_(isinstance(pretty, (str, unicode)))


class MemberNameConversionTest(unittest.TestCase):

  def test_member_to_jsonc(self):
    self.assertEqual(gdata.core._to_jsonc_name(''), '')
    self.assertEqual(gdata.core._to_jsonc_name('foo'), 'foo')
    self.assertEqual(gdata.core._to_jsonc_name('Foo'), 'Foo')
    self.assertEqual(gdata.core._to_jsonc_name('test_x'), 'testX')
    self.assertEqual(gdata.core._to_jsonc_name('test_x_y_zabc'), 'testXYZabc')


def build_test_object():
    return gdata.core.Jsonc(
        api_version='2.0',
        data=gdata.core.Jsonc(
            total_items=800,
            items=[
                gdata.core.Jsonc(
                    view_count=220101,
                    comment_count=22,
                    favorite_count=201,
                    content={
                        '1': ('rtsp://v5.cache3.c.youtube.com'
                              '/CiILENy.../0/0/0/video.3gp')})]))


class JsoncObjectTest(unittest.TestCase):

  def check_video_json(self, x):
    """Validates a JsoncObject similar to VIDEO_EXAMPLE."""
    self.assert_(isinstance(x._dict, dict))
    self.assert_(isinstance(x.data, gdata.core.Jsonc))
    self.assert_(isinstance(x._dict['data'], gdata.core.Jsonc))
    self.assert_(isinstance(x.data._dict, dict))
    self.assert_(isinstance(x._dict['data']._dict, dict))
    self.assert_(isinstance(x._dict['apiVersion'], (str, unicode)))
    self.assert_(isinstance(x.api_version, (str, unicode)))
    self.assert_(isinstance(x.data._dict['items'], list))
    self.assert_(isinstance(x.data.items[0]._dict['commentCount'],
                            (int, long)))
    self.assert_(isinstance(x.data.items[0].favorite_count, (int, long)))
    self.assertEqual(x.data.total_items, 800)
    self.assertEqual(x._dict['data']._dict['totalItems'], 800)
    self.assertEqual(x.data.items[0].view_count, 220101)
    self.assertEqual(x._dict['data']._dict['items'][0]._dict['viewCount'],
                     220101)
    self.assertEqual(x.data.items[0].comment_count, 22)
    self.assertEqual(x.data.items[0]._dict['commentCount'], 22)
    self.assertEqual(x.data.items[0].favorite_count, 201)
    self.assertEqual(x.data.items[0]._dict['favoriteCount'], 201)
    self.assertEqual(
        x.data.items[0].content._dict['1'],
        'rtsp://v5.cache3.c.youtube.com/CiILENy.../0/0/0/video.3gp')
    self.assertEqual(x.api_version, '2.0')
    self.assertEqual(x.api_version, x._dict['apiVersion'])

  def test_convert_to_jsonc(self):
    x = gdata.core._convert_to_jsonc(1)
    self.assert_(isinstance(x, (int, long)))
    self.assertEqual(x, 1)

    x = gdata.core._convert_to_jsonc([1, 'a'])
    self.assert_(isinstance(x, list))
    self.assertEqual(len(x), 2)
    self.assert_(isinstance(x[0], (int, long)))
    self.assertEqual(x[0], 1)
    self.assert_(isinstance(x[1], (str, unicode)))
    self.assertEqual(x[1], 'a')

    x = gdata.core._convert_to_jsonc([{'b': 1}, 'a'])
    self.assert_(isinstance(x, list))
    self.assertEqual(len(x), 2)
    self.assert_(isinstance(x[0], gdata.core.Jsonc))
    self.assertEqual(x[0].b, 1)

  def test_non_json_members(self):
    x = gdata.core.Jsonc(alpha=1, _beta=2, deep={'_bbb': 3, 'aaa': 2})
    x.test = 'a'
    x._bar = 'bacon'
    # Should be able to access the _beta member.
    self.assertEqual(x._beta, 2)
    self.assertEqual(getattr(x, '_beta'), 2)
    try:
      self.assertEqual(getattr(x.deep, '_bbb'), 3)
    except AttributeError:
      pass
    # There should not be a letter 'B' anywhere in the generated JSON.
    self.assertEqual(gdata.core.jsonc_to_string(x).find('B'), -1)
    # We should find a 'b' becuse we don't consider names of dict keys in
    # the constructor as aliases to camelCase names.
    self.assert_(not gdata.core.jsonc_to_string(x).find('b') == -1)

  def test_constructor(self):
    x = gdata.core.Jsonc(a=[{'x': 'y'}, 2])
    self.assert_(isinstance(x, gdata.core.Jsonc))
    self.assert_(isinstance(x.a, list))
    self.assert_(isinstance(x.a[0], gdata.core.Jsonc))
    self.assertEqual(x.a[0].x, 'y')
    self.assertEqual(x.a[1], 2)

  def test_read_json(self):
    x = gdata.core.parse_json(PLAYLIST_EXAMPLE)
    self.assert_(isinstance(x._dict, dict))
    self.assertEqual(x._dict['apiVersion'], '2.0')
    self.assertEqual(x.api_version, '2.0')

    x = gdata.core.parse_json(VIDEO_EXAMPLE)
    self.assert_(isinstance(x._dict, dict))
    self.assertEqual(x._dict['apiVersion'], '2.0')
    self.assertEqual(x.api_version, '2.0')

    x = gdata.core.parse_json(VIDEO_EXAMPLE)
    self.check_video_json(x)

  def test_write_json(self):
    x = gdata.core.Jsonc()
    x._dict['apiVersion'] = '2.0'
    x.data = {'totalItems': 800}
    x.data.items = []
    x.data.items.append(gdata.core.Jsonc(view_count=220101))
    x.data.items[0]._dict['favoriteCount'] = 201
    x.data.items[0].comment_count = 22
    x.data.items[0].content = {
        '1': 'rtsp://v5.cache3.c.youtube.com/CiILENy.../0/0/0/video.3gp'}
    self.check_video_json(x)

  def test_build_using_contructor(self):
    x = build_test_object()
    self.check_video_json(x)

  def test_to_dict(self):
    x = build_test_object()
    self.assertEqual(
        gdata.core._convert_to_object(x),
        {'data': {'totalItems': 800, 'items': [
          {'content': {
            '1': 'rtsp://v5.cache3.c.youtube.com/CiILENy.../0/0/0/video.3gp'},
           'viewCount': 220101, 'commentCount': 22, 'favoriteCount': 201}]},
         'apiVersion': '2.0'})

  def test_try_json_syntax(self):
    x = build_test_object()
    self.assertEqual(x.data.items[0].commentCount, 22)

    x.data.items[0].commentCount = 33
    self.assertEqual(x.data.items[0].commentCount, 33)
    self.assertEqual(x.data.items[0].comment_count, 33)
    self.assertEqual(x.data.items[0]._dict['commentCount'], 33)

  def test_to_string(self):
    self.check_video_json(
        gdata.core.parse_json(
            gdata.core.jsonc_to_string(
                gdata.core._convert_to_object(
                    build_test_object()))))

  def test_del_attr(self):
    x = build_test_object()
    self.assertEqual(x.data.items[0].commentCount, 22)
    del x.data.items[0].comment_count
    try:
      x.data.items[0].commentCount
      self.fail('Should not be able to access commentCount after deletion')
    except AttributeError:
      pass

    self.assertEqual(x.data.items[0].favorite_count, 201)
    del x.data.items[0].favorite_count
    try:
      x.data.items[0].favorite_count
      self.fail('Should not be able to access favorite_count after deletion')
    except AttributeError:
      pass
    try:
      x.data.items[0]._dict['favoriteCount']
      self.fail('Should not see [\'favoriteCount\'] after deletion')
    except KeyError:
      pass

    self.assertEqual(x.data.items[0].view_count, 220101)
    del x.data.items[0]._dict['viewCount']
    try:
      x.data.items[0].view_count
      self.fail('Should not be able to access view_count after deletion')
    except AttributeError:
      pass

    try:
      del x.data.missing
      self.fail('Should not delete a missing attribute')
    except AttributeError:
      pass

  def test_del_protected_attribute(self):
    x = gdata.core.Jsonc(public='x', _private='y')
    self.assertEqual(x.public, 'x')
    self.assertEqual(x._private, 'y')
    self.assertEqual(x['public'], 'x')
    try:
      x['_private']
      self.fail('Should not be able to getitem with _name')
    except KeyError:
      pass

    del x._private
    try:
      x._private
      self.fail('Should not be able to access deleted member')
    except AttributeError:
      pass

  def test_get_set_del_item(self):
    x = build_test_object()

    # Check for expected members using different access patterns.
    self.assert_(isinstance(x._dict, dict))
    self.assert_(isinstance(x['data'], gdata.core.Jsonc))
    self.assert_(isinstance(x._dict['data'], gdata.core.Jsonc))
    self.assert_(isinstance(x['data']._dict, dict))
    self.assert_(isinstance(x._dict['data']._dict, dict))
    self.assert_(isinstance(x['apiVersion'], (str, unicode)))
    try:
      x['api_version']
      self.fail('Should not find using Python style name')
    except KeyError:
      pass
    self.assert_(isinstance(x.data['items'], list))
    self.assert_(isinstance(x.data['items'][0]._dict['commentCount'],
                            (int, long)))
    self.assert_(isinstance(x['data'].items[0]['favoriteCount'], (int, long)))
    self.assertEqual(x['data'].total_items, 800)
    self.assertEqual(x['data']['totalItems'], 800)
    self.assertEqual(x.data['items'][0]['viewCount'], 220101)
    self.assertEqual(x._dict['data'].items[0]._dict['viewCount'],
                     220101)
    self.assertEqual(x['data'].items[0].comment_count, 22)
    self.assertEqual(x.data.items[0]['commentCount'], 22)
    self.assertEqual(x.data.items[0]['favoriteCount'], 201)
    self.assertEqual(x.data.items[0]._dict['favoriteCount'], 201)
    self.assertEqual(
        x.data.items[0].content['1'],
        'rtsp://v5.cache3.c.youtube.com/CiILENy.../0/0/0/video.3gp')
    self.assertEqual(
        x.data.items[0]['content']['1'],
        'rtsp://v5.cache3.c.youtube.com/CiILENy.../0/0/0/video.3gp')
    self.assertEqual(x.api_version, '2.0')
    self.assertEqual(x['apiVersion'], x._dict['apiVersion'])

    # Set properties using setitem
    x['apiVersion'] = '3.2'
    self.assertEqual(x.api_version, '3.2')
    x.data['totalItems'] = 500
    self.assertEqual(x['data'].total_items, 500)
    self.assertEqual(x['data'].items[0].favoriteCount, 201)
    try:
      del x['data']['favoriteCount']
      self.fail('Should not be able to delete missing item')
    except KeyError:
      pass
    del x.data['items'][0]['favoriteCount']
    try:
      x['data'].items[0].favoriteCount
      self.fail('Should not find favoriteCount removed using del item')
    except AttributeError:
      pass


def suite():
  return conf.build_suite([JsoncConversionTest, MemberNameConversionTest,
                           JsoncObjectTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python2.4
#
# Copyright 2008 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Test for Email Migration service."""


__author__ = 'google-apps-apis@googlegroups.com'


import getpass
import unittest
import gdata.apps.migration.service


domain = ''
admin_email = ''
admin_password = ''
username = ''
MESSAGE = """From: joe@blow.com
To: jane@doe.com
Date: Mon, 29 Sep 2008 20:00:34 -0500 (CDT)
Subject: %s

%s"""


class MigrationTest(unittest.TestCase):
  """Test for the MigrationService."""

  def setUp(self):
    self.ms = gdata.apps.migration.service.MigrationService(
        email=admin_email, password=admin_password, domain=domain)
    self.ms.ProgrammaticLogin()

  def testImportMail(self):
    self.ms.ImportMail(user_name=username,
                       mail_message=MESSAGE % ('Test subject', 'Test body'),
                       mail_item_properties=['IS_STARRED'],
                       mail_labels=['Test'])

  def testImportMultipleMails(self):
    for i in xrange(1, 10):
      self.ms.AddMailEntry(mail_message=MESSAGE % ('Test thread %d' % i,
                                                   'Test thread'),
                           mail_item_properties=['IS_UNREAD'],
                           mail_labels=['Test', 'Thread'],
                           identifier=str(i))
    self.ms.ImportMultipleMails(user_name=username)


if __name__ == '__main__':
  print("Google Apps Email Migration Service Tests\n\n"
        "NOTE: Please run these tests only with a test user account.\n")
  domain = raw_input('Google Apps domain: ')
  admin_email = '%s@%s' % (raw_input('Administrator username: '), domain)
  admin_password = getpass.getpass('Administrator password: ')
  username = raw_input('Test username: ')
  unittest.main()



#!/usr/bin/env python
#
#    Copyright (C) 2009 Google Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


# This module is used for version 2 of the Google Data APIs.


__author__ = 'j.s@google.com (Jeff Scudder)'

import unittest
# Tests for v2 features.
import atom_tests.core_test
import atom_tests.data_test
import atom_tests.http_core_test
import atom_tests.auth_test
import atom_tests.mock_http_core_test
import atom_tests.client_test
import gdata_tests.client_test
import gdata_tests.core_test
import gdata_tests.data_test
import gdata_tests.data_smoke_test
import gdata_tests.client_smoke_test
import gdata_tests.live_client_test
import gdata_tests.gauth_test
import gdata_tests.blogger.data_test
import gdata_tests.blogger.live_client_test
import gdata_tests.spreadsheets.data_test
import gdata_tests.spreadsheets.live_client_test
import gdata_tests.projecthosting.data_test
import gdata_tests.projecthosting.live_client_test
import gdata_tests.sites.data_test
import gdata_tests.sites.live_client_test
import gdata_tests.analytics.data_test
import gdata_tests.analytics.live_client_test
import gdata_tests.contacts.live_client_test
import gdata_tests.contacts.profiles.live_client_test
import gdata_tests.calendar_resource.live_client_test
import gdata_tests.calendar_resource.data_test
import gdata_tests.apps.emailsettings.data_test
import gdata_tests.apps.emailsettings.live_client_test
import gdata_tests.apps.multidomain.data_test
import gdata_tests.apps.multidomain.live_client_test
import gdata_tests.youtube.live_client_test


def suite():
  return unittest.TestSuite((
      gdata_tests.contacts.profiles.live_client_test.suite(),
      atom_tests.core_test.suite(),
      atom_tests.data_test.suite(),
      atom_tests.http_core_test.suite(),
      atom_tests.auth_test.suite(),
      atom_tests.mock_http_core_test.suite(),
      atom_tests.client_test.suite(),
      gdata_tests.client_test.suite(),
      gdata_tests.core_test.suite(),
      gdata_tests.data_test.suite(),
      gdata_tests.data_smoke_test.suite(),
      gdata_tests.client_smoke_test.suite(),
      gdata_tests.live_client_test.suite(),
      gdata_tests.gauth_test.suite(),
      gdata_tests.blogger.data_test.suite(),
      gdata_tests.blogger.live_client_test.suite(),
      gdata_tests.spreadsheets.data_test.suite(),
      gdata_tests.spreadsheets.live_client_test.suite(),
      gdata_tests.projecthosting.data_test.suite(),
      gdata_tests.projecthosting.live_client_test.suite(),
      gdata_tests.sites.data_test.suite(),
      gdata_tests.sites.live_client_test.suite(),
      gdata_tests.analytics.data_test.suite(),
      gdata_tests.analytics.live_client_test.suite(),
      gdata_tests.contacts.live_client_test.suite(),
      gdata_tests.calendar_resource.live_client_test.suite(),
      gdata_tests.calendar_resource.data_test.suite(),
      gdata_tests.apps.emailsettings.live_client_test.suite(),
      gdata_tests.apps.emailsettings.data_test.suite(),
      gdata_tests.apps.multidomain.live_client_test.suite(),
      gdata_tests.apps.multidomain.data_test.suite(),
      gdata_tests.youtube.live_client_test.suite(),
      ))


if __name__ == '__main__':
  unittest.TextTestRunner().run(suite())



#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Data model tests for the Organization Unit Provisioning API."""


__author__ = 'Gunjan Sharma <gunjansharma@google.com>'


import unittest
import atom.core
from gdata import test_data
import gdata.apps.organization.data
import gdata.test_config as conf


class CustomerIdEntryTest(unittest.TestCase):

  def setUp(self):
    self.entry = atom.core.parse(test_data.ORGANIZATION_UNIT_CUSTOMER_ID_ENTRY,
                                 gdata.apps.organization.data.CustomerIdEntry)

  def testCustomerIdEntryFromString(self):
    self.assert_(isinstance(self.entry,
                            gdata.apps.organization.data.CustomerIdEntry))
    self.assertEquals(self.entry.customer_id, 'C123A456B')
    self.assertEquals(self.entry.customer_org_unit_name, 'example.com')
    self.assertEquals(self.entry.customer_org_unit_description, 'example.com')
    self.assertEquals(self.entry.org_unit_name, 'example.com')
    self.assertEquals(self.entry.org_unit_description, 'tempdescription')


class OrgUnitEntryTest(unittest.TestCase):

  def setUp(self):
    self.entry = atom.core.parse(test_data.ORGANIZATION_UNIT_ORGUNIT_ENTRY,
                                 gdata.apps.organization.data.OrgUnitEntry)
    self.feed = atom.core.parse(test_data.ORGANIZATION_UNIT_ORGUNIT_FEED,
                                gdata.apps.organization.data.OrgUnitFeed)

  def testOrgUnitEntryFromString(self):
    self.assert_(isinstance(self.entry,
                            gdata.apps.organization.data.OrgUnitEntry))
    self.assertEquals(self.entry.org_unit_description, 'New Test Org')
    self.assertEquals(self.entry.org_unit_name, 'Test Organization')
    self.assertEquals(self.entry.org_unit_path, 'Test/Test+Organization')
    self.assertEquals(self.entry.parent_org_unit_path, 'Test')
    self.assertEquals(self.entry.org_unit_block_inheritance, 'false')

  def testOrgUnitFeedFromString(self):
    self.assertEquals(len(self.feed.entry), 2)
    self.assert_(isinstance(self.feed,
                            gdata.apps.organization.data.OrgUnitFeed))
    self.assert_(isinstance(self.feed.entry[0],
                            gdata.apps.organization.data.OrgUnitEntry))
    self.assert_(isinstance(self.feed.entry[1],
                            gdata.apps.organization.data.OrgUnitEntry))
    self.assertEquals(
        self.feed.entry[0].find_edit_link(),
        ('https://apps-apis.google.com/a/feeds/orgunit/2.0/'
         'C123A456B/testOrgUnit92'))
    self.assertEquals(self.feed.entry[0].org_unit_description, 'test92')
    self.assertEquals(self.feed.entry[0].org_unit_name, 'testOrgUnit92')
    self.assertEquals(self.feed.entry[0].org_unit_path, 'Test/testOrgUnit92')
    self.assertEquals(self.feed.entry[0].parent_org_unit_path, 'Test')
    self.assertEquals(self.feed.entry[0].org_unit_block_inheritance, 'false')
    self.assertEquals(
        self.feed.entry[1].find_edit_link(),
        ('https://apps-apis.google.com/a/feeds/orgunit/2.0/'
         'C123A456B/testOrgUnit93'))
    self.assertEquals(self.feed.entry[1].org_unit_description, 'test93')
    self.assertEquals(self.feed.entry[1].org_unit_name, 'testOrgUnit93')
    self.assertEquals(self.feed.entry[1].org_unit_path, 'Test/testOrgUnit93')
    self.assertEquals(self.feed.entry[1].parent_org_unit_path, 'Test')
    self.assertEquals(self.feed.entry[1].org_unit_block_inheritance, 'false')


class OrgUserEntryTest(unittest.TestCase):

  def setUp(self):
    self.entry = atom.core.parse(test_data.ORGANIZATION_UNIT_ORGUSER_ENTRY,
                                 gdata.apps.organization.data.OrgUserEntry)
    self.feed = atom.core.parse(test_data.ORGANIZATION_UNIT_ORGUSER_FEED,
                                gdata.apps.organization.data.OrgUserFeed)

  def testOrgUserEntryFromString(self):
    self.assert_(isinstance(self.entry,
                            gdata.apps.organization.data.OrgUserEntry))
    self.assertEquals(self.entry.user_email, 'admin@example.com')
    self.assertEquals(self.entry.org_unit_path, 'Test')

  def testOrgUserFeedFromString(self):
    self.assertEquals(len(self.feed.entry), 2)
    self.assert_(isinstance(self.feed,
                            gdata.apps.organization.data.OrgUserFeed))
    self.assert_(isinstance(self.feed.entry[0],
                            gdata.apps.organization.data.OrgUserEntry))
    self.assert_(isinstance(self.feed.entry[1],
                            gdata.apps.organization.data.OrgUserEntry))
    self.assertEquals(
        self.feed.entry[0].find_edit_link(),
        ('https://apps-apis.google.com/a/feeds/orguser/2.0/'
         'C123A456B/user720430%40example.com'))
    self.assertEquals(self.feed.entry[0].user_email, 'user720430@example.com')
    self.assertEquals(self.feed.entry[0].org_unit_path, 'Test')
    self.assertEquals(
        self.feed.entry[1].find_edit_link(),
        ('https://apps-apis.google.com/a/feeds/orguser/2.0/'
         'C123A456B/user832648%40example.com'))
    self.assertEquals(self.feed.entry[1].user_email, 'user832648@example.com')
    self.assertEquals(self.feed.entry[1].org_unit_path, 'Test')


def suite():
  return conf.build_suite([OrgUnitEntryTest, OrgUserEntryTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python
#
# Copyright (C) 2006 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__author__ = 'j.s@google.com (Jeff Scudder)'

import os
import unittest
import atom.service
import atom.mock_http_core
import gdata.test_config as conf

class AtomServiceUnitTest(unittest.TestCase):
  
  def testBuildUriWithNoParams(self):
    x = atom.service.BuildUri('/base/feeds/snippets')
    self.assert_(x == '/base/feeds/snippets')

  def testBuildUriWithParams(self):
    # Add parameters to a URI
    x = atom.service.BuildUri('/base/feeds/snippets', url_params={'foo': 'bar', 
                                                     'bq': 'digital camera'})
    self.assert_(x == '/base/feeds/snippets?foo=bar&bq=digital+camera')
    self.assert_(x.startswith('/base/feeds/snippets'))
    self.assert_(x.count('?') == 1)
    self.assert_(x.count('&') == 1)
    self.assert_(x.index('?') < x.index('&'))
    self.assert_(x.index('bq=digital+camera') != -1)

    # Add parameters to a URI that already has parameters
    x = atom.service.BuildUri('/base/feeds/snippets?bq=digital+camera', 
                             url_params={'foo': 'bar', 'max-results': '250'})
    self.assert_(x.startswith('/base/feeds/snippets?bq=digital+camera'))
    self.assert_(x.count('?') == 1)
    self.assert_(x.count('&') == 2)
    self.assert_(x.index('?') < x.index('&'))
    self.assert_(x.index('max-results=250') != -1)
    self.assert_(x.index('foo=bar') != -1)


  def testBuildUriWithoutParameterEscaping(self):
    x = atom.service.BuildUri('/base/feeds/snippets', 
            url_params={'foo': ' bar', 'bq': 'digital camera'}, 
            escape_params=False)
    self.assert_(x.index('foo= bar') != -1)
    self.assert_(x.index('bq=digital camera') != -1)

  def testParseHttpUrl(self):
    atom_service = atom.service.AtomService('code.google.com')
    self.assertEquals(atom_service.server, 'code.google.com')
    (host, port, ssl, path) =  atom.service.ProcessUrl(atom_service,
        'http://www.google.com/service/subservice?name=value')

    self.assertEquals(ssl, False)
    self.assertEquals(host, 'www.google.com')
    self.assertEquals(port, 80)
    self.assertEquals(path, '/service/subservice?name=value')

  def testParseHttpUrlWithPort(self):
    atom_service = atom.service.AtomService('code.google.com')
    self.assertEquals(atom_service.server, 'code.google.com')
    (host, port, ssl, path) =  atom.service.ProcessUrl(atom_service,
        'http://www.google.com:12/service/subservice?name=value&newname=newvalue')

    self.assertEquals(ssl, False)
    self.assertEquals(host, 'www.google.com')
    self.assertEquals(port, 12)
    self.assert_(path.startswith('/service/subservice?'))
    self.assert_(path.find('name=value') >= len('/service/subservice?'))
    self.assert_(path.find('newname=newvalue') >= len('/service/subservice?'))

  def testParseHttpsUrl(self):
    atom_service = atom.service.AtomService('code.google.com')
    self.assertEquals(atom_service.server, 'code.google.com')
    (host, port, ssl, path) =  atom.service.ProcessUrl(atom_service,
        'https://www.google.com/service/subservice?name=value&newname=newvalue')

    self.assertEquals(ssl, True)
    self.assertEquals(host, 'www.google.com')
    self.assertEquals(port, 443)
    self.assert_(path.startswith('/service/subservice?'))
    self.assert_(path.find('name=value') >= len('/service/subservice?'))
    self.assert_(path.find('newname=newvalue') >= len('/service/subservice?'))

  def testParseHttpsUrlWithPort(self):
    atom_service = atom.service.AtomService('code.google.com')
    self.assertEquals(atom_service.server, 'code.google.com')
    (host, port, ssl, path) =  atom.service.ProcessUrl(atom_service,
        'https://www.google.com:13981/service/subservice?name=value&newname=newvalue')

    self.assertEquals(ssl, True)
    self.assertEquals(host, 'www.google.com')
    self.assertEquals(port, 13981)
    self.assert_(path.startswith('/service/subservice?'))
    self.assert_(path.find('name=value') >= len('/service/subservice?'))
    self.assert_(path.find('newname=newvalue') >= len('/service/subservice?'))

  def testSetBasicAuth(self):
    client = atom.service.AtomService()
    client.UseBasicAuth('foo', 'bar')
    token = client.token_store.find_token('http://')
    self.assert_(isinstance(token, atom.service.BasicAuthToken))
    self.assertEquals(token.auth_header, 'Basic Zm9vOmJhcg==')
    client.UseBasicAuth('','')
    token = client.token_store.find_token('http://')
    self.assert_(isinstance(token, atom.service.BasicAuthToken))
    self.assertEquals(token.auth_header, 'Basic Og==')

  def testProcessUrlWithStringForService(self):
    (server, port, ssl, uri) = atom.service.ProcessUrl(
        service='www.google.com', url='/base/feeds/items')
    self.assertEquals(server, 'www.google.com')
    self.assertEquals(port, 80)
    self.assertEquals(ssl, False)
    self.assert_(uri.startswith('/base/feeds/items'))

    client = atom.service.AtomService()
    client.server = 'www.google.com'
    client.ssl = True
    (server, port, ssl, uri) = atom.service.ProcessUrl(
        service=client, url='/base/feeds/items')
    self.assertEquals(server, 'www.google.com')
    self.assertEquals(ssl, True)
    self.assert_(uri.startswith('/base/feeds/items'))

    (server, port, ssl, uri) = atom.service.ProcessUrl(service=None,
        url='https://www.google.com/base/feeds/items')
    self.assertEquals(server, 'www.google.com')
    self.assertEquals(port, 443)
    self.assertEquals(ssl, True)
    self.assert_(uri.startswith('/base/feeds/items'))

  def testHostHeaderContainsNonDefaultPort(self):
    client = atom.service.AtomService()
    client.http_client.v2_http_client = atom.mock_http_core.EchoHttpClient()
    response = client.Get('http://example.com')
    self.assertEqual(response.getheader('Echo-Host'), 'example.com:None')
    response = client.Get('https://example.com')
    self.assertEqual(response.getheader('Echo-Host'), 'example.com:None')
    response = client.Get('https://example.com:8080')
    self.assertEqual(response.getheader('Echo-Host'), 'example.com:8080')
    response = client.Get('http://example.com:1234')
    self.assertEqual(response.getheader('Echo-Host'), 'example.com:1234')

  def testBadHttpsProxyRaisesRealException(self):
    """Test that real exceptions are raised when there is an error connecting to
    a host with an https proxy
    """
    client = atom.service.AtomService(server='example.com')
    client.server = 'example.com'
    os.environ['https_proxy'] = 'http://example.com'
    self.assertRaises(atom.http.ProxyError,
        atom.service.PrepareConnection, client, 'https://example.com')


def suite():
  return conf.build_suite([AtomServiceUnitTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python
#
# Copyright (C) 2008 Yu-Jie Lin
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import urllib

import gdata.webmastertools.service
import gdata.service
try:
  from xml.etree import ElementTree
except ImportError:
  from elementtree import ElementTree
import atom
import getpass


username = ''
password = ''

username = raw_input('Please enter your username: ')
password = getpass.getpass()

client = gdata.webmastertools.service.GWebmasterToolsService(
    email=username, 
    password=password, source='PythonWebmasterToolsSample-1')

EXAMPLE_SITE = 'http://www.example.com/'
EXAMPLE_SITEMAP = 'http://www.example.com/sitemap-index.xml'


def safeElementText(element):
  if hasattr(element, 'text'):
     return element.text
  return ''


print 'Logging in'
client.ProgrammaticLogin()

print
print 'Adding site: %s' % EXAMPLE_SITE
entry = client.AddSite(EXAMPLE_SITE)

print
print "%-25s %25s %25s" % ('Site', 'Last Updated', 'Last Crawled')
print '='*80
print "%-25s %25s %25s" % (
  entry.title.text.replace('http://', '')[:25], entry.updated.text[:25],
  safeElementText(entry.crawled)[:25])
print "  Preferred: %-23s Indexed: %5s        GeoLoc: %10s" % (
  safeElementText(entry.preferred_domain)[:30], entry.indexed.text[:5],
  safeElementText(entry.geolocation)[:10])
print "  Crawl rate: %-10s            Verified: %5s" % (
  safeElementText(entry.crawl_rate)[:10], entry.verified.text[:5])

# Verifying a site. This sample won't do this since we don't own example.com
#client.VerifySite(EXAMPLE_SITE, 'htmlpage')

# The following needs the ownership of the site
#client.UpdateGeoLocation(EXAMPLE_SITE, 'US')
#client.UpdateCrawlRate(EXAMPLE_SITE, 'normal')
#client.UpdatePreferredDomain(EXAMPLE_SITE, 'preferwww')
#client.UpdateEnhancedImageSearch(EXAMPLE_SITE, 'true')

print
print 'Adding sitemap: %s' % EXAMPLE_SITEMAP
entry = client.AddSitemap(EXAMPLE_SITE, EXAMPLE_SITEMAP)

print entry.title.text.replace('http://', '')[:80]
print "  Last Updated   : %29s              Status: %10s" % (
    entry.updated.text[:29], entry.sitemap_status.text[:10])
print "  Last Downloaded: %29s           URL Count: %10s" % (
    safeElementText(entry.sitemap_last_downloaded)[:29],
    safeElementText(entry.sitemap_url_count)[:10])

# Add a mobile sitemap
#entry = client.AddMobileSitemap(EXAMPLE_SITE, 'http://.../sitemap-mobile-example.xml', 'XHTML')

# Add a news sitemap, your site must be included in Google News.
# See also http://google.com/support/webmasters/bin/answer.py?answer=42738
#entry = client.AddNewsSitemap(EXAMPLE_SITE, 'http://.../sitemap-news-example.xml', 'Label')

print
print 'Deleting sitemap: %s' % EXAMPLE_SITEMAP
client.DeleteSitemap(EXAMPLE_SITE, EXAMPLE_SITEMAP)

print
print 'Deleting site: %s' % EXAMPLE_SITE
client.DeleteSite(EXAMPLE_SITE)
print



#!/usr/bin/env python
#
# Copyright (C) 2010 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit Tests for Google Analytics Data Export API and Management APIs.

Although the Data Export API and Management API conceptually operate on
different parts of Google Analytics, the APIs share some code so they
are released in the same module.

AccountFeedTest: All unit tests for AccountFeed class.
DataFeedTest: All unit tests for DataFeed class.
ManagementFeedAccountTest: Unit tests for ManagementFeed class.
ManagementFeedGoalTest: Unit tests for ManagementFeed class.
ManagementFeedAdvSegTest: Unit tests for ManagementFeed class.
"""

__author__ = 'api.nickm@google.com (Nick Mihailovski)'


import unittest
from gdata import test_data
import gdata.analytics.data
import atom.core
import gdata.test_config as conf


class AccountFeedTest(unittest.TestCase):
  """Unit test for all custom elements in the Account Feed."""

  def setUp(self):
    """Retrieves the test XML feed into a AccountFeed object."""
    self.feed = atom.core.parse(test_data.ANALYTICS_ACCOUNT_FEED,
                                gdata.analytics.data.AccountFeed)

  def testSegment(self):
    """Tests Segment class in Google Analytics Account Feed."""

    segment = self.feed.segment[0]
    self.assertEquals(segment.id, 'gaid::-11')
    self.assertEquals(segment.name, 'Visits from iPhones')

  def testSegmentDefinition(self):
    """Tests Definition class in Google Analytics Account Feed."""

    definition = self.feed.segment[0].definition
    self.assertEquals(definition.text, 'ga:operatingSystem==iPhone')

  def testEntryTableId(self):
    """Tests custom classes in Google Analytics Account Feed."""

    entry = self.feed.entry[0]
    self.assertEquals(entry.table_id.text, 'ga:1174')

  def testEntryProperty(self):
    """Tests the property classes in Google Analytics Account Feed."""
    property = self.feed.entry[0].property

    self.assertEquals(property[0].name, 'ga:accountId')
    self.assertEquals(property[0].value, '30481')

    self.assertEquals(property[1].name, 'ga:accountName')
    self.assertEquals(property[1].value, 'Google Store')

    self.assertEquals(property[2].name, 'ga:profileId')
    self.assertEquals(property[2].value, '1174')

    self.assertEquals(property[3].name, 'ga:webPropertyId')
    self.assertEquals(property[3].value, 'UA-30481-1')

    self.assertEquals(property[4].name, 'ga:currency')
    self.assertEquals(property[4].value, 'USD')

    self.assertEquals(property[5].name, 'ga:timezone')
    self.assertEquals(property[5].value, 'America/Los_Angeles')

  def testEntryGetProperty(self):
    """Tests GetProperty inherited class in the AccountEntry class."""

    entry = self.feed.entry[0]
    self.assertEquals(entry.GetProperty('ga:accountId').value, '30481')
    self.assertEquals(entry.GetProperty('ga:accountName').value, 'Google Store')
    self.assertEquals(entry.GetProperty('ga:profileId').value, '1174')
    self.assertEquals(entry.GetProperty('ga:webPropertyId').value, 'UA-30481-1')
    self.assertEquals(entry.GetProperty('ga:currency').value, 'USD')
    self.assertEquals(entry.GetProperty('ga:timezone').value, 'America/Los_Angeles')

  def testGoal(self):
    """Tests Goal class in Google Anlaytics Account Feed."""

    goal = self.feed.entry[0].goal[0]
    self.assertEquals(goal.number, '1')
    self.assertEquals(goal.name, 'Completing Order')
    self.assertEquals(goal.value, '10.0')
    self.assertEquals(goal.active, 'true')

  def testDestination(self):
    """Tests Destination class in Google Analytics Account Feed."""

    destination = self.feed.entry[0].goal[0].destination
    self.assertEquals(destination.expression, '/purchaseComplete.html')
    self.assertEquals(destination.case_sensitive, 'false')
    self.assertEquals(destination.match_type, 'regex')
    self.assertEquals(destination.step1_required, 'false')

  def testStep(self):
    """Tests Step class in Google Analytics Account Feed."""

    step = self.feed.entry[0].goal[0].destination.step[0]
    self.assertEquals(step.number, '1')
    self.assertEquals(step.name, 'View Product Categories')
    self.assertEquals(step.path, '/Apps|Accessories|Fun|Kid\+s|Office')

  def testEngagemet(self):
    """Tests Engagement class in Google Analytics Account Feed."""

    engagement = self.feed.entry[0].goal[1].engagement
    self.assertEquals(engagement.type, 'timeOnSite')
    self.assertEquals(engagement.comparison, '>')
    self.assertEquals(engagement.threshold_value, '300')

  def testCustomVariable(self):
    """Tests CustomVariable class in Google Analytics Account Feed."""

    customVar = self.feed.entry[0].custom_variable[0]
    self.assertEquals(customVar.index, '1')
    self.assertEquals(customVar.name, 'My Custom Variable')
    self.assertEquals(customVar.scope, '3')


class DataFeedTest(unittest.TestCase):
  """Unit test for all custom elements in the Data Feed."""

  def setUp(self):
    """Retrieves the test XML feed into a DataFeed object."""

    self.feed = atom.core.parse(test_data.ANALYTICS_DATA_FEED,
                                gdata.analytics.data.DataFeed)

  def testDataFeed(self):
    """Tests custom classes in Google Analytics Data Feed."""

    self.assertEquals(self.feed.start_date.text, '2008-10-01')
    self.assertEquals(self.feed.end_date.text, '2008-10-31')

  def testAggregates(self):
    """Tests Aggregates class in Google Analytics Data Feed."""

    self.assert_(self.feed.aggregates is not None)

  def testContainsSampledData(self):
    """Tests ContainsSampledData class in Google Analytics Data Feed."""

    contains_sampled_data = self.feed.contains_sampled_data.text
    self.assertEquals(contains_sampled_data, 'true')
    self.assertTrue(self.feed.HasSampledData())

  def testAggregatesElements(self):
    """Tests Metrics class in Aggregates class."""

    metric = self.feed.aggregates.metric[0]
    self.assertEquals(metric.confidence_interval, '0.0')
    self.assertEquals(metric.name, 'ga:visits')
    self.assertEquals(metric.type, 'integer')
    self.assertEquals(metric.value, '136540')

    metric = self.feed.aggregates.GetMetric('ga:visits')
    self.assertEquals(metric.confidence_interval, '0.0')
    self.assertEquals(metric.name, 'ga:visits')
    self.assertEquals(metric.type, 'integer')
    self.assertEquals(metric.value, '136540')

  def testDataSource(self):
    """Tests DataSources class in Google Analytics Data Feed."""

    self.assert_(self.feed.data_source[0] is not None)

  def testDataSourceTableId(self):
    """Tests TableId class in the DataSource class."""

    table_id = self.feed.data_source[0].table_id
    self.assertEquals(table_id.text, 'ga:1174')

  def testDataSourceTableName(self):
    """Tests TableName class in the DataSource class."""

    table_name = self.feed.data_source[0].table_name
    self.assertEquals(table_name.text, 'www.googlestore.com')

  def testDataSourceProperty(self):
    """Tests Property class in the DataSource class."""

    property = self.feed.data_source[0].property
    self.assertEquals(property[0].name, 'ga:profileId')
    self.assertEquals(property[0].value, '1174')

    self.assertEquals(property[1].name, 'ga:webPropertyId')
    self.assertEquals(property[1].value, 'UA-30481-1')

    self.assertEquals(property[2].name, 'ga:accountName')
    self.assertEquals(property[2].value, 'Google Store')

  def testDataSourceGetProperty(self):
    """Tests GetProperty utility method in the DataSource class."""

    ds = self.feed.data_source[0]
    self.assertEquals(ds.GetProperty('ga:profileId').value, '1174')
    self.assertEquals(ds.GetProperty('ga:webPropertyId').value, 'UA-30481-1')
    self.assertEquals(ds.GetProperty('ga:accountName').value, 'Google Store')

  def testSegment(self):
    """Tests Segment class in DataFeed class."""

    segment = self.feed.segment
    self.assertEquals(segment.id, 'gaid::-11')
    self.assertEquals(segment.name, 'Visits from iPhones')

  def testSegmentDefinition(self):
    """Tests Definition class in Segment class."""

    definition = self.feed.segment.definition
    self.assertEquals(definition.text, 'ga:operatingSystem==iPhone')

  def testEntryDimension(self):
    """Tests Dimension class in Entry class."""

    dim = self.feed.entry[0].dimension[0]
    self.assertEquals(dim.name, 'ga:source')
    self.assertEquals(dim.value, 'blogger.com')

  def testEntryGetDimension(self):
    """Tests GetDimension utility method in the Entry class."""

    dim = self.feed.entry[0].GetDimension('ga:source')
    self.assertEquals(dim.name, 'ga:source')
    self.assertEquals(dim.value, 'blogger.com')

    error = self.feed.entry[0].GetDimension('foo')
    self.assertEquals(error, None)

  def testEntryMetric(self):
    """Tests Metric class in Entry class."""

    met = self.feed.entry[0].metric[0]
    self.assertEquals(met.confidence_interval, '0.0')
    self.assertEquals(met.name, 'ga:visits')
    self.assertEquals(met.type, 'integer')
    self.assertEquals(met.value, '68140')

  def testEntryGetMetric(self):
    """Tests GetMetric utility method in the Entry class."""

    met = self.feed.entry[0].GetMetric('ga:visits')
    self.assertEquals(met.confidence_interval, '0.0')
    self.assertEquals(met.name, 'ga:visits')
    self.assertEquals(met.type, 'integer')
    self.assertEquals(met.value, '68140')

    error = self.feed.entry[0].GetMetric('foo')
    self.assertEquals(error, None)

  def testEntryGetObject(self):
    """Tests GetObjectOf utility method in Entry class."""

    entry = self.feed.entry[0]

    dimension = entry.GetObject('ga:source')
    self.assertEquals(dimension.name, 'ga:source')
    self.assertEquals(dimension.value, 'blogger.com')

    metric = entry.GetObject('ga:visits')
    self.assertEquals(metric.name, 'ga:visits')
    self.assertEquals(metric.value, '68140')
    self.assertEquals(metric.type, 'integer')
    self.assertEquals(metric.confidence_interval, '0.0')

    error = entry.GetObject('foo')
    self.assertEquals(error, None)


class ManagementFeedProfileTest(unittest.TestCase):
  """Unit test for all property elements in Google Analytics Management Feed.

  Since the Account, Web Property and Profile feed all have the same
  structure and XML elements, this single test case covers all three feeds.
  """

  def setUp(self):
    """Retrieves the test XML feed into a DataFeed object."""

    self.feed = atom.core.parse(test_data.ANALYTICS_MGMT_PROFILE_FEED,
                                gdata.analytics.data.ManagementFeed)

  def testFeedKindAttribute(self):
    """Tests the kind attribute in the feed."""

    self.assertEqual(self.feed.kind, 'analytics#profiles')

  def testEntryKindAttribute(self):
    """tests the kind attribute in the entry."""

    entry_kind = self.feed.entry[0].kind
    self.assertEqual(entry_kind, 'analytics#profile')

  def testEntryProperty(self):
    """Tests property classes in Managment Entry class."""

    property = self.feed.entry[0].property
    self.assertEquals(property[0].name, 'ga:accountId')
    self.assertEquals(property[0].value, '30481')

  def testEntryGetProperty(self):
    """Tests GetProperty helper method in Management Entry class."""

    entry = self.feed.entry[0]
    self.assertEquals(entry.GetProperty('ga:accountId').value, '30481')

  def testGetParentLinks(self):
    """Tests GetParentLinks utility method."""

    parent_links = self.feed.entry[0].GetParentLinks()
    self.assertEquals(len(parent_links), 1)

    parent_link = parent_links[0]
    self.assertEquals(parent_link.rel,
        'http://schemas.google.com/ga/2009#parent')
    self.assertEquals(parent_link.type,
        'application/atom+xml')
    self.assertEquals(parent_link.href,
        'https://www.google.com/analytics/feeds/datasources'
        '/ga/accounts/30481/webproperties/UA-30481-1')
    self.assertEquals(parent_link.target_kind,
        'analytics#webproperty')

  def testGetChildLinks(self):
    """Tests GetChildLinks utility method."""

    child_links = self.feed.entry[0].GetChildLinks()
    self.assertEquals(len(child_links), 1)

    self.ChildLinkTestHelper(child_links[0])

  def testGetChildLink(self):
    """Tests getChildLink utility method."""

    child_link = self.feed.entry[0].GetChildLink('analytics#goals')
    self.ChildLinkTestHelper(child_link)

    child_link = self.feed.entry[0].GetChildLink('foo_bar')
    self.assertEquals(child_link, None)

  def ChildLinkTestHelper(self, child_link):
    """Common method to test a child link."""

    self.assertEquals(child_link.rel,
        'http://schemas.google.com/ga/2009#child')
    self.assertEquals(child_link.type,
        'application/atom+xml')
    self.assertEquals(child_link.href,
        'https://www.google.com/analytics/feeds/datasources'
        '/ga/accounts/30481/webproperties/UA-30481-1/profiles/1174/goals')
    self.assertEquals(child_link.target_kind,
        'analytics#goals')


class ManagementFeedGoalTest(unittest.TestCase):
  """Unit test for all Goal elements in Management Feed."""

  def setUp(self):
    """Retrieves the test XML feed into a DataFeed object."""

    self.feed = atom.core.parse(test_data.ANALYTICS_MGMT_GOAL_FEED,
                                gdata.analytics.data.ManagementFeed)

  def testEntryGoal(self):
    """Tests Goal class in Google Anlaytics Account Feed."""

    goal = self.feed.entry[0].goal
    self.assertEquals(goal.number, '1')
    self.assertEquals(goal.name, 'Completing Order')
    self.assertEquals(goal.value, '10.0')
    self.assertEquals(goal.active, 'true')

  def testGoalDestination(self):
    """Tests Destination class in Google Analytics Account Feed."""

    destination = self.feed.entry[0].goal.destination
    self.assertEquals(destination.expression, '/purchaseComplete.html')
    self.assertEquals(destination.case_sensitive, 'false')
    self.assertEquals(destination.match_type, 'regex')
    self.assertEquals(destination.step1_required, 'false')

  def testGoalDestinationStep(self):
    """Tests Step class in Google Analytics Account Feed."""

    step = self.feed.entry[0].goal.destination.step[0]
    self.assertEquals(step.number, '1')
    self.assertEquals(step.name, 'View Product Categories')
    self.assertEquals(step.path, '/Apps|Accessories')

  def testGoalEngagemet(self):
    """Tests Engagement class in Google Analytics Account Feed."""

    engagement = self.feed.entry[1].goal.engagement
    self.assertEquals(engagement.type, 'timeOnSite')
    self.assertEquals(engagement.comparison, '>')
    self.assertEquals(engagement.threshold_value, '300')


class ManagementFeedAdvSegTest(unittest.TestCase):
  """Unit test for all Advanced Segment elements in Management Feed."""

  def setUp(self):
    """Retrieves the test XML feed into a DataFeed object."""

    self.feed = atom.core.parse(test_data.ANALYTICS_MGMT_ADV_SEGMENT_FEED,
                                gdata.analytics.data.ManagementFeed)

  def testEntrySegment(self):
    """Tests Segment class in ManagementEntry class."""

    segment = self.feed.entry[0].segment
    self.assertEquals(segment.id, 'gaid::0')
    self.assertEquals(segment.name, 'Sources Form Google')

  def testSegmentDefinition(self):
    """Tests Definition class in Segment class."""

    definition = self.feed.entry[0].segment.definition
    self.assertEquals(definition.text, 'ga:source=~^\Qgoogle\E')


def suite():
  """Test Account Feed, Data Feed and Management API Feeds."""
  return conf.build_suite([
      AccountFeedTest,
      DataFeedTest,
      ManagementFeedProfileTest,
      ManagementFeedGoalTest,
      ManagementFeedAdvSegTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

__author__ = ('api.jfisher (Jeff Fisher), '
              'api.eric@google.com (Eric Bidelman)')

import getpass
import os
import re
import StringIO
import time
import unittest

import gdata.docs.service
import gdata.spreadsheet.service


username = ''
password = ''

client = gdata.docs.service.DocsService()
editClient = gdata.docs.service.DocsService()
spreadsheets = gdata.spreadsheet.service.SpreadsheetsService()


class DocumentsListServiceTest(unittest.TestCase):
  def setUp(self):
    self.client = client
    self.editClient = editClient
    self.editClient.SetClientLoginToken(client.GetClientLoginToken())
    self.editClient.additional_headers = {'If-Match': '*'}
    self.spreadsheets = spreadsheets
    self.DOCUMENT_CATEGORY = client._MakeKindCategory(gdata.docs.service.DOCUMENT_LABEL)
    self.SPREADSHEET_CATEGORY = client._MakeKindCategory(gdata.docs.service.SPREADSHEET_LABEL)
    self.PRESENTATION_CATEGORY = client._MakeKindCategory(gdata.docs.service.PRESENTATION_LABEL)


class DocumentListQueryTest(DocumentsListServiceTest):

  def setUp(self):
    DocumentsListServiceTest.setUp(self)
    self.feed = self.client.GetDocumentListFeed()

  def testGetDocumentsListFeed(self):
    self.assert_(isinstance(self.feed, gdata.docs.DocumentListFeed))
    uri = 'http://docs.google.com/feeds/documents/private/full/?max-results=1'

    # Query using GetDocumentListFeed()
    feed = self.client.GetDocumentListFeed(uri)
    self.assert_(isinstance(feed, gdata.docs.DocumentListFeed))
    self.assertEqual(len(feed.entry), 1)
    self.assertEqual(self.feed.entry[0].id.text, feed.entry[0].id.text)
    self.assertEqual(self.feed.entry[0].title.text, feed.entry[0].title.text)

    # Query using QueryDocumentListFeed()
    feed2 = self.client.QueryDocumentListFeed(uri)
    self.assertEqual(len(feed2.entry), 1)
    self.assertEqual(self.feed.entry[0].id.text, feed2.entry[0].id.text)
    self.assertEqual(self.feed.entry[0].title.text, feed2.entry[0].title.text)

  def testGetDocumentsListEntry(self):
    self_link = self.feed.entry[0].GetSelfLink().href
    entry = self.client.GetDocumentListEntry(self_link)
    self.assert_(isinstance(entry, gdata.docs.DocumentListEntry))
    self.assertEqual(self.feed.entry[0].id.text, entry.id.text)
    self.assertEqual(self.feed.entry[0].title.text, entry.title.text)

    self.assert_(self.feed.entry[0].resourceId.text is not None)
    self.assert_(self.feed.entry[0].lastModifiedBy is not None)
    self.assert_(self.feed.entry[0].lastViewed is not None)

  def testGetDocumentsListAclFeed(self):
    uri = ('http://docs.google.com/feeds/documents/private/full/'
           '-/mine?max-results=1')
    feed = self.client.GetDocumentListFeed(uri)
    feed_link = feed.entry[0].GetAclLink().href
    acl_feed = self.client.GetDocumentListAclFeed(feed_link)
    self.assert_(isinstance(acl_feed, gdata.docs.DocumentListAclFeed))
    self.assert_(isinstance(acl_feed.entry[0], gdata.docs.DocumentListAclEntry))
    self.assert_(acl_feed.entry[0].scope is not None)
    self.assert_(acl_feed.entry[0].role is not None)


class DocumentListAclTest(DocumentsListServiceTest):

  def setUp(self):
    DocumentsListServiceTest.setUp(self)
    uri = ('http://docs.google.com/feeds/documents/private/full'
           '/-/mine?max-results=1')
    self.feed = self.client.GetDocumentListFeed(uri)

    self.EMAIL = 'x@example.com'
    self.SCOPE_TYPE = 'user'
    self.ROLE_VALUE = 'reader'

  def testCreateAndUpdateAndDeleteAcl(self):
    # Add new ACL
    scope = gdata.docs.Scope(value=self.EMAIL, type=self.SCOPE_TYPE)
    role = gdata.docs.Role(value=self.ROLE_VALUE)

    acl_entry = self.client.Post(
        gdata.docs.DocumentListAclEntry(scope=scope, role=role),
        self.feed.entry[0].GetAclLink().href,
        converter=gdata.docs.DocumentListAclEntryFromString)
    self.assert_(isinstance(acl_entry, gdata.docs.DocumentListAclEntry))
    self.assertEqual(acl_entry.scope.value, self.EMAIL)
    self.assertEqual(acl_entry.scope.type, self.SCOPE_TYPE)
    self.assertEqual(acl_entry.role.value, self.ROLE_VALUE)

    # Update the user's role
    ROLE_VALUE = 'writer'
    acl_entry.role.value = ROLE_VALUE

    updated_acl_entry = self.editClient.Put(
        acl_entry, acl_entry.GetEditLink().href,
        converter=gdata.docs.DocumentListAclEntryFromString)

    self.assertEqual(updated_acl_entry.scope.value, self.EMAIL)
    self.assertEqual(updated_acl_entry.scope.type, self.SCOPE_TYPE)
    self.assertEqual(updated_acl_entry.role.value, ROLE_VALUE)

    # Delete the ACL
    self.editClient.Delete(updated_acl_entry.GetEditLink().href)

    # Make sure entry was actually deleted
    acl_feed = self.client.GetDocumentListAclFeed(
        self.feed.entry[0].GetAclLink().href)
    for acl_entry in acl_feed.entry:
      self.assert_(acl_entry.scope.value != self.EMAIL)


class DocumentListCreateAndDeleteTest(DocumentsListServiceTest):
  def setUp(self):
    DocumentsListServiceTest.setUp(self)
    self.BLANK_TITLE = "blank.txt"
    self.TITLE = 'Test title'
    self.new_entry = gdata.docs.DocumentListEntry()
    self.new_entry.category.append(self.DOCUMENT_CATEGORY)

  def testCreateAndDeleteEmptyDocumentSlugHeaderTitle(self):
    created_entry = self.client.Post(self.new_entry,
                                      '/feeds/documents/private/full',
                                      extra_headers={'Slug': self.BLANK_TITLE})
    self.editClient.Delete(created_entry.GetEditLink().href)
    self.assertEqual(created_entry.title.text, self.BLANK_TITLE)
    self.assertEqual(created_entry.category[0].label, 'document')

  def testCreateAndDeleteEmptyDocumentAtomTitle(self):
    self.new_entry.title = gdata.atom.Title(text=self.TITLE)
    created_entry = self.client.Post(self.new_entry,
                                      '/feeds/documents/private/full')
    self.editClient.Delete(created_entry.GetEditLink().href)
    self.assertEqual(created_entry.title.text, self.TITLE)
    self.assertEqual(created_entry.category[0].label, 'document')

  def testCreateAndDeleteEmptySpreadsheet(self):
    self.new_entry.title = gdata.atom.Title(text=self.TITLE)
    self.new_entry.category[0] = self.SPREADSHEET_CATEGORY
    created_entry = self.client.Post(self.new_entry,
                                      '/feeds/documents/private/full')
    self.editClient.Delete(created_entry.GetEditLink().href)
    self.assertEqual(created_entry.title.text, self.TITLE)
    self.assertEqual(created_entry.category[0].label, 'viewed')
    self.assertEqual(created_entry.category[1].label, 'spreadsheet')

  def testCreateAndDeleteEmptyPresentation(self):
    self.new_entry.title = gdata.atom.Title(text=self.TITLE)
    self.new_entry.category[0] = self.PRESENTATION_CATEGORY
    created_entry = self.client.Post(self.new_entry,
                                      '/feeds/documents/private/full')
    self.editClient.Delete(created_entry.GetEditLink().href)
    self.assertEqual(created_entry.title.text, self.TITLE)
    self.assertEqual(created_entry.category[0].label, 'viewed')
    self.assertEqual(created_entry.category[1].label, 'presentation')

  def testCreateAndDeleteFolder(self):
    folder_name = 'TestFolder'
    folder = self.client.CreateFolder(folder_name)
    self.assertEqual(folder.title.text, folder_name)
    self.editClient.Delete(folder.GetEditLink().href)

  def testCreateAndDeleteFolderInFolder(self):
    DEST_FOLDER_NAME = 'TestFolder'
    dest_folder = self.client.CreateFolder(DEST_FOLDER_NAME)

    CREATED_FOLDER_NAME = 'TestFolder2'
    new_folder = self.client.CreateFolder(CREATED_FOLDER_NAME, dest_folder)

    for category in new_folder.category:
      if category.scheme.startswith(gdata.docs.service.FOLDERS_SCHEME_PREFIX):
        self.assertEqual(new_folder.category[0].label, DEST_FOLDER_NAME)
        break

    # delete the folders we created, this will also delete the child folder
    dest_folder = self.client.Get(dest_folder.GetSelfLink().href)
    self.editClient.Delete(dest_folder.GetEditLink().href)


class DocumentListMoveInAndOutOfFolderTest(DocumentsListServiceTest):
  def setUp(self):
    DocumentsListServiceTest.setUp(self)
    self.folder_name = 'TestFolder'
    self.folder = self.client.CreateFolder(self.folder_name)

    self.doc_title = 'TestDoc'
    self.ms = gdata.MediaSource(file_path='test.doc',
                                content_type='application/msword')

  def tearDown(self):
    folder = self.client.Get(self.folder.GetSelfLink().href)
    self.editClient.Delete(folder.GetEditLink().href)

  def testUploadDocumentToFolder(self):
    created_entry = self.client.Upload(self.ms, self.doc_title,
                                        self.folder)
    for category in created_entry.category:
      if category.scheme.startswith(gdata.docs.service.FOLDERS_SCHEME_PREFIX):
        self.assertEqual(category.label, self.folder_name)
        break

    # delete the doc we created
    created_entry = self.client.Get(created_entry.GetSelfLink().href)
    match = re.search('\/(document%3A[^\/]*)\/?.*?\/(.*)$',
                      created_entry.GetEditLink().href)
    edit_uri = 'http://docs.google.com/feeds/documents/private/full/'
    edit_uri += '%s/%s' % (match.group(1), match.group(2))
    self.editClient.Delete(edit_uri)

  def testMoveDocumentInAndOutOfFolder(self):
    created_entry = self.client.Upload(self.ms, self.doc_title)
    moved_entry = self.client.MoveIntoFolder(created_entry,
                                             self.folder)
    for category in moved_entry.category:
      if category.scheme.startswith(gdata.docs.service.FOLDERS_SCHEME_PREFIX):
        self.assertEqual(category.label, self.folder_name)
        break

    self.editClient.MoveOutOfFolder(moved_entry)
    moved_entry = self.client.Get(moved_entry.GetSelfLink().href)
    for category in moved_entry.category:
      starts_with_folder__prefix = category.scheme.startswith(
          gdata.docs.service.FOLDERS_SCHEME_PREFIX)
      self.assert_(not starts_with_folder__prefix)

    created_entry = self.client.Get(created_entry.GetSelfLink().href)
    self.editClient.Delete(created_entry.GetEditLink().href)

  def testMoveFolderIntoFolder(self):
    dest_folder_name = 'DestFolderName'
    dest_folder = self.client.CreateFolder(dest_folder_name)
    self.client.MoveIntoFolder(self.folder, dest_folder)

    self.folder = self.client.Get(self.folder.GetSelfLink().href)
    folder_was_moved = False
    for category in self.folder.category:
      if category.term == dest_folder_name:
        folder_was_moved = True
        break
    self.assert_(folder_was_moved)

    #cleanup
    dest_folder = self.client.Get(dest_folder.GetSelfLink().href)
    self.editClient.Delete(dest_folder.GetEditLink().href)


class DocumentListUploadTest(DocumentsListServiceTest):

  def testUploadAndDeleteDocument(self):
    ms = gdata.MediaSource(file_path='test.doc',
                           content_type='application/msword')
    entry = self.client.Upload(ms, 'test doc')
    self.assertEqual(entry.title.text, 'test doc')
    self.assertEqual(entry.category[0].label, 'document')
    self.assert_(isinstance(entry, gdata.docs.DocumentListEntry))
    self.editClient.Delete(entry.GetEditLink().href)

  def testUploadAndDeletePresentation(self):
    ms = gdata.MediaSource(file_path='test.ppt',
                           content_type='application/vnd.ms-powerpoint')
    entry = self.client.Upload(ms, 'test preso')
    self.assertEqual(entry.title.text, 'test preso')
    self.assertEqual(entry.category[0].label, 'viewed')
    self.assertEqual(entry.category[1].label, 'presentation')
    self.assert_(isinstance(entry, gdata.docs.DocumentListEntry))
    self.editClient.Delete(entry.GetEditLink().href)

  def testUploadAndDeleteSpreadsheet(self):
    ms = gdata.MediaSource(file_path='test.csv',
                           content_type='text/csv')
    entry = self.client.Upload(ms, 'test spreadsheet')
    self.assert_(entry.title.text == 'test spreadsheet')
    self.assertEqual(entry.category[0].label, 'viewed')
    self.assertEqual(entry.category[1].label, 'spreadsheet')
    self.assert_(isinstance(entry, gdata.docs.DocumentListEntry))
    self.editClient.Delete(entry.GetEditLink().href)


class DocumentListUpdateTest(DocumentsListServiceTest):
  def setUp(self):
    DocumentsListServiceTest.setUp(self)
    self.TITLE = 'CreatedTestDoc'
    new_entry = gdata.docs.DocumentListEntry()
    new_entry.title = gdata.atom.Title(text=self.TITLE)
    new_entry.category.append(self.DOCUMENT_CATEGORY)
    self.created_entry = self.client.Post(new_entry,
                                          '/feeds/documents/private/full')

  def tearDown(self):
    # Delete the test doc we created
    self_link = self.created_entry.GetSelfLink().href
    entry = self.client.GetDocumentListEntry(self_link)
    self.editClient.Delete(entry.GetEditLink().href)

  def testUpdateDocumentMetadataAndContent(self):
    title = 'UpdatedTestDoc'
    # Update metadata
    self.created_entry.title.text = title
    updated_entry = self.editClient.Put(self.created_entry,
                                    self.created_entry.GetEditLink().href)
    self.assertEqual(updated_entry.title.text, title)

    # Update document's content
    ms = gdata.MediaSource(file_path='test.doc',
                           content_type='application/msword')
    uri = updated_entry.GetEditMediaLink().href
    updated_entry = self.editClient.Put(ms, uri)
    self.assertEqual(updated_entry.title.text, title)

    # Append content to document
    data = 'data to append'
    ms = gdata.MediaSource(file_handle=StringIO.StringIO(data),
                           content_type='text/plain',
                           content_length=len(data))
    uri = updated_entry.GetEditMediaLink().href + '?append=true'
    updated_entry = self.editClient.Put(ms, uri)


class DocumentListExportTest(DocumentsListServiceTest):

  def testExportDocument(self):
    query = ('https://docs.google.com/feeds/documents/private/full'
             '/-/document?max-results=1')
    feed = self.client.QueryDocumentListFeed(query)
    file_paths = ['./downloadedTest.doc', './downloadedTest.html',
                  './downloadedTest.odt', './downloadedTest.pdf',
                  './downloadedTest.png', './downloadedTest.rtf',
                  './downloadedTest.txt', './downloadedTest.zip']
    for path in file_paths:
      self.client.Export(feed.entry[0], path)
      self.assert_(os.path.exists(path))
      self.assert_(os.path.getsize(path))
      os.remove(path)

  def testExportPresentation(self):
    query = ('https://docs.google.com/feeds/documents/private/full'
             '/-/presentation?max-results=1')
    feed = self.client.QueryDocumentListFeed(query)
    file_paths = ['./downloadedTest.pdf', './downloadedTest.ppt',
                  './downloadedTest.swf', './downloadedTest.txt']
    for path in file_paths:
      self.client.Export(feed.entry[0].resourceId.text, path)
      self.assert_(os.path.exists(path))
      self.assert_(os.path.getsize(path))
      os.remove(path)

  def testExportSpreadsheet(self):
    query = ('https://docs.google.com/feeds/documents/private/full'
             '/-/spreadsheet?max-results=1')
    feed = self.client.QueryDocumentListFeed(query)
    file_paths = ['./downloadedTest.xls', './downloadedTest.csv',
                  './downloadedTest.pdf', './downloadedTest.ods',
                  './downloadedTest.tsv', './downloadedTest.html']
    docs_token = self.client.GetClientLoginToken()
    self.client.SetClientLoginToken(self.spreadsheets.GetClientLoginToken())
    for path in file_paths:
      self.client.Export(feed.entry[0], path)
      self.assert_(os.path.exists(path))
      self.assert_(os.path.getsize(path) > 0)
      os.remove(path)
    self.client.SetClientLoginToken(docs_token)

  def testExportNonExistentDocument(self):
    path = './ned.txt'
    exception_raised = False
    try:
      self.client.Export('non_existent_doc', path)
    except Exception, e:  # expected
      exception_raised = True
      self.assert_(exception_raised)
      self.assert_(not os.path.exists(path))

if __name__ == '__main__':
  print ('DocList API Tests\nNOTE: Please run these tests only with a test '
         'account. The tests may delete or update your data.')
  username = raw_input('Please enter your username: ')
  password = getpass.getpass()
  if client.GetClientLoginToken() is None:
    client.ClientLogin(username, password,
                       source='Document List Client Unit Tests')
  if spreadsheets.GetClientLoginToken() is None:
    spreadsheets.ClientLogin(username, password,
                             source='Document List Client Unit Tests')

  unittest.main()



#!/usr/bin/python
#
# Copyright (C) 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This file demonstrates how to use the Google Data API's Python client library
# to interface with the Codesearch service.


__author__ = 'vbarathan@gmail.com (Prakash Barathan)'


from gdata import service
import gdata.codesearch.service
import gdata
import atom
import getopt
import sys


class CodesearchExample:

  def __init__(self):
    """Creates a GData service instance to talk to Codesearch service."""
    self.service = gdata.codesearch.service.CodesearchService(
        source='Codesearch_Python_Sample-1.0')

  def PrintCodeSnippets(self, query):
    """Prints the codesearch results for given query."""
    feed = self.service.GetSnippetsFeed(query)
    print feed.title.text + " Results for '" +  query + "'"
    print '============================================'
    for entry in feed.entry:
      print "" + entry.title.text
      for match in entry.match:
        print "\tline#" + match.line_number + ":" + match.text.replace('\n', '')
    print


def main():
  """The main function runs the CodesearchExample application with user
  specified query."""

  # parse command line options
  try:
    opts, args = getopt.getopt(sys.argv[1:], "", ["query="])
  except getopt.error, msg:
    print ('python CodesearchExample.py --query [query_text]')
    sys.exit(2)

  query = ''

  # Process options
  for o, a in opts:
    if o == "--query":
      query = a

  if query == '':
    print ('python CodesearchExample.py --query [query]')
    sys.exit(2)

  sample = CodesearchExample()
  sample.PrintCodeSnippets(query)


if __name__ == '__main__':
  main()



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import getpass

from gdata.contentforshopping.client import ContentForShoppingClient

# Gather merchant information
account_id = raw_input('Merchant Account ID? ').strip()
email = raw_input('Google Email Address? ').strip()

# Create a client
client = ContentForShoppingClient(account_id)

# Perform programmatic login
client.client_login(email, getpass.getpass('Google Password? '),
    'Shopping API for Content sample', 'structuredcontent')

# Get the products list from the products feed
product_feed = client.get_products()

print 'Listing: %s result(s)' % product_feed.total_results.text

# Each product is an element in the feed's entry (a list)
for product in product_feed.entry:
  print '- %s: %s' % (product.title.text, product.content.text)
